pub struct DebugStruct<'a, 'b>where
'b: 'a,{ /* private fields */ }Expand description
A struct to help with fmt::Debug implementations.
This is useful when you wish to output a formatted struct as a part of your
Debug::fmt implementation.
This can be constructed by the Formatter::debug_struct method.
Examples
use std::fmt;
struct Foo {
bar: i32,
baz: String,
}
impl fmt::Debug for Foo {
fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
fmt.debug_struct("Foo")
.field("bar", &self.bar)
.field("baz", &self.baz)
.finish()
}
}
assert_eq!(
format!("{:?}", Foo { bar: 10, baz: "Hello World".to_string() }),
r#"Foo { bar: 10, baz: "Hello World" }"#,
);Implementations
Sourceimpl<'a, 'b> DebugStruct<'a, 'b>where
'b: 'a,
impl<'a, 'b> DebugStruct<'a, 'b>where
'b: 'a,
1.2.0 · Sourcepub fn field(
&mut self,
name: &str,
value: &dyn Debug,
) -> &mut DebugStruct<'a, 'b>
pub fn field( &mut self, name: &str, value: &dyn Debug, ) -> &mut DebugStruct<'a, 'b>
Adds a new field to the generated struct output.
Examples
use std::fmt;
struct Bar {
bar: i32,
another: String,
}
impl fmt::Debug for Bar {
fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
fmt.debug_struct("Bar")
.field("bar", &self.bar) // We add `bar` field.
.field("another", &self.another) // We add `another` field.
// We even add a field which doesn't exist (because why not?).
.field("nonexistent_field", &1)
.finish() // We're good to go!
}
}
assert_eq!(
format!("{:?}", Bar { bar: 10, another: "Hello World".to_string() }),
r#"Bar { bar: 10, another: "Hello World", nonexistent_field: 1 }"#,
);Sourcepub fn field_with<F>(
&mut self,
name: &str,
value_fmt: F,
) -> &mut DebugStruct<'a, 'b>
🔬This is a nightly-only experimental API. (debug_closure_helpers)
pub fn field_with<F>( &mut self, name: &str, value_fmt: F, ) -> &mut DebugStruct<'a, 'b>
debug_closure_helpers)Adds a new field to the generated struct output.
This method is equivalent to DebugStruct::field, but formats the
value using a provided closure rather than by calling Debug::fmt.
1.53.0 · Sourcepub fn finish_non_exhaustive(&mut self) -> Result<(), Error>
pub fn finish_non_exhaustive(&mut self) -> Result<(), Error>
Marks the struct as non-exhaustive, indicating to the reader that there are some other fields that are not shown in the debug representation.
Examples
use std::fmt;
struct Bar {
bar: i32,
hidden: f32,
}
impl fmt::Debug for Bar {
fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
fmt.debug_struct("Bar")
.field("bar", &self.bar)
.finish_non_exhaustive() // Show that some other field(s) exist.
}
}
assert_eq!(
format!("{:?}", Bar { bar: 10, hidden: 1.0 }),
"Bar { bar: 10, .. }",
);1.2.0 · Sourcepub fn finish(&mut self) -> Result<(), Error>
pub fn finish(&mut self) -> Result<(), Error>
Finishes output and returns any error encountered.
Examples
use std::fmt;
struct Bar {
bar: i32,
baz: String,
}
impl fmt::Debug for Bar {
fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
fmt.debug_struct("Bar")
.field("bar", &self.bar)
.field("baz", &self.baz)
.finish() // You need to call it to "finish" the
// struct formatting.
}
}
assert_eq!(
format!("{:?}", Bar { bar: 10, baz: "Hello World".to_string() }),
r#"Bar { bar: 10, baz: "Hello World" }"#,
);Trait Implementations
Sourceimpl Visit for DebugStruct<'_, '_>
impl Visit for DebugStruct<'_, '_>
Sourcefn record_debug(&mut self, field: &Field, value: &dyn Debug)
fn record_debug(&mut self, field: &Field, value: &dyn Debug)
Visit a value implementing
fmt::Debug.Sourcefn record_f64(&mut self, field: &Field, value: f64)
fn record_f64(&mut self, field: &Field, value: f64)
Visit a double-precision floating point value.
Sourcefn record_i64(&mut self, field: &Field, value: i64)
fn record_i64(&mut self, field: &Field, value: i64)
Visit a signed 64-bit integer value.
Sourcefn record_u64(&mut self, field: &Field, value: u64)
fn record_u64(&mut self, field: &Field, value: u64)
Visit an unsigned 64-bit integer value.
Sourcefn record_i128(&mut self, field: &Field, value: i128)
fn record_i128(&mut self, field: &Field, value: i128)
Visit a signed 128-bit integer value.
Sourcefn record_u128(&mut self, field: &Field, value: u128)
fn record_u128(&mut self, field: &Field, value: u128)
Visit an unsigned 128-bit integer value.
Sourcefn record_bool(&mut self, field: &Field, value: bool)
fn record_bool(&mut self, field: &Field, value: bool)
Visit a boolean value.
Sourcefn record_str(&mut self, field: &Field, value: &str)
fn record_str(&mut self, field: &Field, value: &str)
Visit a string value.
Sourcefn record_bytes(&mut self, field: &Field, value: &[u8])
fn record_bytes(&mut self, field: &Field, value: &[u8])
Visit a byte slice.