pub struct Error { /* private fields */ }alloc_io)Expand description
Implementations
Sourceimpl Error
impl Error
1.0.0 ยท Sourcepub fn raw_os_error(&self) -> Option<i32>
pub fn raw_os_error(&self) -> Option<i32>
Returns the OS error that this error represents (if any).
If this Error was constructed via last_os_error or
from_raw_os_error, then this function will return Some, otherwise
it will return None.
Examples
use std::io::{Error, ErrorKind};
fn print_os_error(err: &Error) {
if let Some(raw_os_err) = err.raw_os_error() {
println!("raw OS error: {raw_os_err:?}");
} else {
println!("Not an OS error");
}
}
fn main() {
// Will print "raw OS error: ...".
print_os_error(&Error::last_os_error());
// Will print "Not an OS error".
print_os_error(&Error::new(ErrorKind::Other, "oh no!"));
}1.3.0 ยท Sourcepub fn get_ref(&self) -> Option<&(dyn Error + Sync + Send + 'static)>
pub fn get_ref(&self) -> Option<&(dyn Error + Sync + Send + 'static)>
Returns a reference to the inner error wrapped by this error (if any).
If this Error was constructed via new then this function will
return Some, otherwise it will return None.
Examples
use std::io::{Error, ErrorKind};
fn print_error(err: &Error) {
if let Some(inner_err) = err.get_ref() {
println!("Inner error: {inner_err:?}");
} else {
println!("No inner error");
}
}
fn main() {
// Will print "No inner error".
print_error(&Error::last_os_error());
// Will print "Inner error: ...".
print_error(&Error::new(ErrorKind::Other, "oh no!"));
}1.3.0 ยท Sourcepub fn get_mut(&mut self) -> Option<&mut (dyn Error + Sync + Send + 'static)>
pub fn get_mut(&mut self) -> Option<&mut (dyn Error + Sync + Send + 'static)>
Returns a mutable reference to the inner error wrapped by this error (if any).
If this Error was constructed via new then this function will
return Some, otherwise it will return None.
Examples
use std::io::{Error, ErrorKind};
use std::{error, fmt};
use std::fmt::Display;
#[derive(Debug)]
struct MyError {
v: String,
}
impl MyError {
fn new() -> MyError {
MyError {
v: "oh no!".to_string()
}
}
fn change_message(&mut self, new_message: &str) {
self.v = new_message.to_string();
}
}
impl error::Error for MyError {}
impl Display for MyError {
fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
write!(f, "MyError: {}", self.v)
}
}
fn change_error(mut err: Error) -> Error {
if let Some(inner_err) = err.get_mut() {
inner_err.downcast_mut::<MyError>().unwrap().change_message("I've been changed!");
}
err
}
fn print_error(err: &Error) {
if let Some(inner_err) = err.get_ref() {
println!("Inner error: {inner_err}");
} else {
println!("No inner error");
}
}
fn main() {
// Will print "No inner error".
print_error(&change_error(Error::last_os_error()));
// Will print "Inner error: ...".
print_error(&change_error(Error::new(ErrorKind::Other, MyError::new())));
}1.0.0 ยท Sourcepub fn kind(&self) -> ErrorKind
pub fn kind(&self) -> ErrorKind
Returns the corresponding ErrorKind for this error.
This may be a value set by Rust code constructing custom io::Errors,
or if this io::Error was sourced from the operating system,
it will be a value inferred from the systemโs error encoding.
See last_os_error for more details.
Examples
use std::io::{Error, ErrorKind};
fn print_error(err: Error) {
println!("{:?}", err.kind());
}
fn main() {
// As no error has (visibly) occurred, this may print anything!
// It likely prints a placeholder for unidentified (non-)errors.
print_error(Error::last_os_error());
// Will print "AddrInUse".
print_error(Error::new(ErrorKind::AddrInUse, "oh no!"));
}Sourceimpl Error
impl Error
1.0.0 ยท Sourcepub fn last_os_error() -> Error
pub fn last_os_error() -> Error
Returns an error representing the last OS error which occurred.
This function reads the value of errno for the target platform (e.g.
GetLastError on Windows) and will return a corresponding instance of
Error for the error code.
This should be called immediately after a call to a platform function, otherwise the state of the error value is indeterminate. In particular, other standard library functions may call platform functions that may (or may not) reset the error value even if they succeed.
Examples
use std::io::Error;
let os_error = Error::last_os_error();
println!("last OS error: {os_error:?}");1.0.0 ยท Sourcepub fn from_raw_os_error(code: i32) -> Error
pub fn from_raw_os_error(code: i32) -> Error
Creates a new instance of an Error from a particular OS error code.
Examples
On Linux:
use std::io;
let error = io::Error::from_raw_os_error(22);
assert_eq!(error.kind(), io::ErrorKind::InvalidInput);On Windows:
use std::io;
let error = io::Error::from_raw_os_error(10022);
assert_eq!(error.kind(), io::ErrorKind::InvalidInput);Sourceimpl Error
impl Error
1.0.0 ยท Sourcepub fn new<E>(kind: ErrorKind, error: E) -> Error
pub fn new<E>(kind: ErrorKind, error: E) -> Error
Creates a new I/O error from a known kind of error as well as an arbitrary error payload.
This function is used to generically create I/O errors which do not
originate from the OS itself. The error argument is an arbitrary
payload which will be contained in this Error.
Note that this function allocates memory on the heap.
If no extra payload is required, use the From conversion from
ErrorKind.
Examples
use std::io::{Error, ErrorKind};
// errors can be created from strings
let custom_error = Error::new(ErrorKind::Other, "oh no!");
// errors can also be created from other errors
let custom_error2 = Error::new(ErrorKind::Interrupted, custom_error);
// creating an error without payload (and without memory allocation)
let eof_error = Error::from(ErrorKind::UnexpectedEof);1.74.0 ยท Sourcepub fn other<E>(error: E) -> Error
pub fn other<E>(error: E) -> Error
Creates a new I/O error from an arbitrary error payload.
This function is used to generically create I/O errors which do not
originate from the OS itself. It is a shortcut for Error::new
with ErrorKind::Other.
Examples
use std::io::Error;
// errors can be created from strings
let custom_error = Error::other("oh no!");
// errors can also be created from other errors
let custom_error2 = Error::other(custom_error);1.3.0 ยท Sourcepub fn into_inner(self) -> Option<Box<dyn Error + Sync + Send>>
pub fn into_inner(self) -> Option<Box<dyn Error + Sync + Send>>
Consumes the Error, returning its inner error (if any).
If this Error was constructed via new or other,
then this function will return Some,
otherwise it will return None.
Examples
use std::io::{Error, ErrorKind};
fn print_error(err: Error) {
if let Some(inner_err) = err.into_inner() {
println!("Inner error: {inner_err}");
} else {
println!("No inner error");
}
}
fn main() {
// Will print "No inner error".
print_error(Error::last_os_error());
// Will print "Inner error: ...".
print_error(Error::new(ErrorKind::Other, "oh no!"));
}1.79.0 ยท Sourcepub fn downcast<E>(self) -> Result<E, Error>
pub fn downcast<E>(self) -> Result<E, Error>
Attempts to downcast the custom boxed error to E.
If this Error contains a custom boxed error,
then it would attempt downcasting on the boxed error,
otherwise it will return Err.
If the custom boxed error has the same type as E, it will return Ok,
otherwise it will also return Err.
This method is meant to be a convenience routine for calling
Box<dyn Error + Sync + Send>::downcast on the custom boxed error, returned by
Error::into_inner.
Examples
use std::fmt;
use std::io;
use std::error::Error;
#[derive(Debug)]
enum E {
Io(io::Error),
SomeOtherVariant,
}
impl fmt::Display for E {
// ...
}
impl Error for E {}
impl From<io::Error> for E {
fn from(err: io::Error) -> E {
err.downcast::<E>()
.unwrap_or_else(E::Io)
}
}
impl From<E> for io::Error {
fn from(err: E) -> io::Error {
match err {
E::Io(io_error) => io_error,
e => io::Error::new(io::ErrorKind::Other, e),
}
}
}
let e = E::SomeOtherVariant;
// Convert it to an io::Error
let io_error = io::Error::from(e);
// Cast it back to the original variant
let e = E::from(io_error);
assert!(matches!(e, E::SomeOtherVariant));
let io_error = io::Error::from(io::ErrorKind::AlreadyExists);
// Convert it to E
let e = E::from(io_error);
// Cast it back to the original variant
let io_error = io::Error::from(e);
assert_eq!(io_error.kind(), io::ErrorKind::AlreadyExists);
assert!(io_error.get_ref().is_none());
assert!(io_error.raw_os_error().is_none());Trait Implementations
1.0.0 ยท Sourceimpl Error for Error
impl Error for Error
Sourcefn cause(&self) -> Option<&dyn Error>
fn cause(&self) -> Option<&dyn Error>
replaced by Error::source, which can support downcasting
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
1.0.0 ยท Sourcefn description(&self) -> &str
fn description(&self) -> &str
use the Display impl or to_string()
Sourceimpl<T> From<AsyncFdTryNewError<T>> for Error
impl<T> From<AsyncFdTryNewError<T>> for Error
Sourcefn from(value: AsyncFdTryNewError<T>) -> Error
fn from(value: AsyncFdTryNewError<T>) -> Error
Sourceimpl<S, E> From<ConversionError<S, E>> for Errorwhere
E: Display,
Boxes the error into an io::Error, dropping the retained file descriptor in the process.
impl<S, E> From<ConversionError<S, E>> for Errorwhere
E: Display,
Boxes the error into an io::Error, dropping the retained file descriptor in the process.
Sourcefn from(e: ConversionError<S, E>) -> Error
fn from(e: ConversionError<S, E>) -> Error
Sourceimpl From<DecodeError> for Error
Available on crate feature std only.
impl From<DecodeError> for Error
std only.Sourcefn from(error: DecodeError) -> Error
fn from(error: DecodeError) -> Error
Sourceimpl From<EncodeError> for Error
Available on crate feature std only.
impl From<EncodeError> for Error
std only.Sourcefn from(error: EncodeError) -> Error
fn from(error: EncodeError) -> Error
Sourceimpl From<Error> for Error
Available on crate feature std only.
impl From<Error> for Error
std only.Sourcefn from(j: Error) -> Error
fn from(j: Error) -> Error
Convert a serde_json::Error into an io::Error.
JSON syntax and data errors are turned into InvalidData I/O errors.
EOF errors are turned into UnexpectedEof I/O errors.
use std::io;
enum MyError {
Io(io::Error),
Json(serde_json::Error),
}
impl From<serde_json::Error> for MyError {
fn from(err: serde_json::Error) -> MyError {
use serde_json::error::Category;
match err.classify() {
Category::Io => {
MyError::Io(err.into())
}
Category::Syntax | Category::Data | Category::Eof => {
MyError::Json(err)
}
}
}
}1.14.0 ยท Sourceimpl From<ErrorKind> for Error
Intended for use for errors not exposed to the user, where allocating onto
the heap (for normal construction via Error::new) is too costly.
impl From<ErrorKind> for Error
Intended for use for errors not exposed to the user, where allocating onto the heap (for normal construction via Error::new) is too costly.
1.0.0 ยท Sourceimpl<W> From<IntoInnerError<W>> for Error
impl<W> From<IntoInnerError<W>> for Error
Sourcefn from(iie: IntoInnerError<W>) -> Error
fn from(iie: IntoInnerError<W>) -> Error
Sourceimpl From<MultiError> for Error
impl From<MultiError> for Error
Sourcefn from(e: MultiError) -> Error
fn from(e: MultiError) -> Error
1.0.0 ยท Sourceimpl From<NulError> for Error
Available on non-no_global_oom_handling and non-no_rc and non-no_sync only.
impl From<NulError> for Error
no_global_oom_handling and non-no_rc and non-no_sync only.Sourcefn from(e: ShareError) -> Error
fn from(e: ShareError) -> Error
Sourceimpl From<TryGetError> for Error
Available on crate feature std only.
impl From<TryGetError> for Error
std only.Sourcefn from(error: TryGetError) -> Error
fn from(error: TryGetError) -> Error
1.89.0 ยท Sourceimpl From<TryLockError> for Error
impl From<TryLockError> for Error
Sourcefn from(err: TryLockError) -> Error
fn from(err: TryLockError) -> Error
1.78.0 ยท Sourceimpl From<TryReserveError> for Error
impl From<TryReserveError> for Error
Sourcefn from(_: TryReserveError) -> Error
fn from(_: TryReserveError) -> Error
Converts TryReserveError to an error with ErrorKind::OutOfMemory.
TryReserveError wonโt be available as the error source(),
but this may change in the future.