pub enum Utf8Pattern<'a> {
StringPattern(&'a str),
CharPattern(char),
}๐ฌThis is a nightly-only experimental API. (
pattern)Expand description
Result of calling Pattern::as_utf8_pattern().
Can be used for inspecting the contents of a Pattern in cases
where the underlying representation can be represented as UTF-8.
Variants
StringPattern(&'a str)
๐ฌThis is a nightly-only experimental API. (
pattern)Type returned by String and str types.
This stores str rather than bytes so callers cannot describe
non-UTF-8 string patterns through this API.
CharPattern(char)
๐ฌThis is a nightly-only experimental API. (
pattern)Type returned by char types.