Payload

Enum Payload 

pub enum Payload {
Show 149 variants SubscribePayload(SubscribePayload), UnsubscribePayload(UnsubscribePayload), SetSelectablePayload(bool), OpenFilePayload(OpenFilePayload), OpenFileFloatingPayload(OpenFilePayload), OpenTerminalPayload(OpenFilePayload), OpenTerminalFloatingPayload(OpenFilePayload), OpenCommandPanePayload(OpenCommandPanePayload), OpenCommandPaneFloatingPayload(OpenCommandPanePayload), SwitchTabToPayload(SwitchTabToPayload), SetTimeoutPayload(SetTimeoutPayload), ExecCmdPayload(ExecCmdPayload), PostMessageToPayload(PluginMessagePayload), PostMessageToPluginPayload(PluginMessagePayload), ShowSelfPayload(bool), SwitchToModePayload(SwitchToModePayload), NewTabsWithLayoutPayload(String), ResizePayload(ResizePayload), ResizeWithDirectionPayload(ResizePayload), MoveFocusPayload(MovePayload), MoveFocusOrTabPayload(MovePayload), WritePayload(Vec<u8>), WriteCharsPayload(String), MovePaneWithDirectionPayload(MovePayload), GoToTabNamePayload(String), FocusOrCreateTabPayload(String), GoToTabPayload(u32), StartOrReloadPluginPayload(String), CloseTerminalPanePayload(u32), ClosePluginPanePayload(u32), FocusTerminalPanePayload(PaneIdAndShouldFloat), FocusPluginPanePayload(PaneIdAndShouldFloat), RenameTerminalPanePayload(IdAndNewName), RenamePluginPanePayload(IdAndNewName), RenameTabPayload(IdAndNewName), ReportCrashPayload(String), RequestPluginPermissionPayload(RequestPluginPermissionPayload), SwitchSessionPayload(SwitchSessionPayload), OpenFileInPlacePayload(OpenFilePayload), OpenTerminalInPlacePayload(OpenFilePayload), OpenCommandPaneInPlacePayload(OpenCommandPanePayload), RunCommandPayload(RunCommandPayload), WebRequestPayload(WebRequestPayload), DeleteDeadSessionPayload(String), RenameSessionPayload(String), UnblockCliPipeInputPayload(String), BlockCliPipeInputPayload(String), CliPipeOutputPayload(CliPipeOutputPayload), MessageToPluginPayload(MessageToPluginPayload), KillSessionsPayload(KillSessionsPayload), ScanHostFolderPayload(String), NewTabsWithLayoutInfoPayload(NewTabsWithLayoutInfoPayload), ReconfigurePayload(ReconfigurePayload), HidePaneWithIdPayload(HidePaneWithIdPayload), ShowPaneWithIdPayload(ShowPaneWithIdPayload), OpenCommandPaneBackgroundPayload(OpenCommandPanePayload), RerunCommandPanePayload(RerunCommandPanePayload), ResizePaneIdWithDirectionPayload(ResizePaneIdWithDirectionPayload), EditScrollbackForPaneWithIdPayload(EditScrollbackForPaneWithIdPayload), WriteToPaneIdPayload(WriteToPaneIdPayload), WriteCharsToPaneIdPayload(WriteCharsToPaneIdPayload), MovePaneWithPaneIdPayload(MovePaneWithPaneIdPayload), MovePaneWithPaneIdInDirectionPayload(MovePaneWithPaneIdInDirectionPayload), ClearScreenForPaneIdPayload(ClearScreenForPaneIdPayload), ScrollUpInPaneIdPayload(ScrollUpInPaneIdPayload), ScrollDownInPaneIdPayload(ScrollDownInPaneIdPayload), ScrollToTopInPaneIdPayload(ScrollToTopInPaneIdPayload), ScrollToBottomInPaneIdPayload(ScrollToBottomInPaneIdPayload), PageScrollUpInPaneIdPayload(PageScrollUpInPaneIdPayload), PageScrollDownInPaneIdPayload(PageScrollDownInPaneIdPayload), TogglePaneIdFullscreenPayload(TogglePaneIdFullscreenPayload), TogglePaneEmbedOrEjectForPaneIdPayload(TogglePaneEmbedOrEjectForPaneIdPayload), CloseTabWithIndexPayload(CloseTabWithIndexPayload), BreakPanesToNewTabPayload(BreakPanesToNewTabPayload), BreakPanesToTabWithIndexPayload(BreakPanesToTabWithIndexPayload), ReloadPluginPayload(ReloadPluginPayload), LoadNewPluginPayload(LoadNewPluginPayload), RebindKeysPayload(RebindKeysPayload), ChangeHostFolderPayload(ChangeHostFolderPayload), SetFloatingPanePinnedPayload(SetFloatingPanePinnedPayload), StackPanesPayload(StackPanesPayload), ChangeFloatingPanesCoordinatesPayload(ChangeFloatingPanesCoordinatesPayload), OpenCommandPaneNearPluginPayload(OpenCommandPaneNearPluginPayload), OpenTerminalNearPluginPayload(OpenTerminalNearPluginPayload), OpenTerminalFloatingNearPluginPayload(OpenTerminalFloatingNearPluginPayload), OpenTerminalInPlaceOfPluginPayload(OpenTerminalInPlaceOfPluginPayload), OpenCommandPaneFloatingNearPluginPayload(OpenCommandPaneFloatingNearPluginPayload), OpenCommandPaneInPlaceOfPluginPayload(OpenCommandPaneInPlaceOfPluginPayload), OpenFileNearPluginPayload(OpenFileNearPluginPayload), OpenFileFloatingNearPluginPayload(OpenFileFloatingNearPluginPayload), OpenFileInPlaceOfPluginPayload(OpenFileInPlaceOfPluginPayload), GroupAndUngroupPanesPayload(GroupAndUngroupPanesPayload), HighlightAndUnhighlightPanesPayload(HighlightAndUnhighlightPanesPayload), CloseMultiplePanesPayload(CloseMultiplePanesPayload), FloatMultiplePanesPayload(FloatMultiplePanesPayload), EmbedMultiplePanesPayload(EmbedMultiplePanesPayload), SetSelfMouseSelectionSupportPayload(SetSelfMouseSelectionSupportPayload), GenerateWebLoginTokenPayload(GenerateWebLoginTokenPayload), RevokeWebLoginTokenPayload(RevokeWebLoginTokenPayload), RenameWebLoginTokenPayload(RenameWebLoginTokenPayload), ReplacePaneWithExistingPanePayload(ReplacePaneWithExistingPanePayload), NewTabPayload(NewTabPayload), GetPaneScrollbackPayload(GetPaneScrollbackPayload), RunActionPayload(RunActionPayload), ShowCursorPayload(ShowCursorPayload), CopyToClipboardPayload(CopyToClipboardPayload), SendSigintToPaneIdPayload(PaneId), SendSigkillToPaneIdPayload(PaneId), GetPanePidPayload(GetPanePidPayload), OverrideLayoutPayload(OverrideLayoutPayload), SaveLayoutPayload(SaveLayoutPayload), DeleteLayoutPayload(DeleteLayoutPayload), EditLayoutPayload(EditLayoutPayload), GenerateRandomNamePayload(GenerateRandomNamePayload), DumpLayoutPayload(DumpLayoutPayload), ParseLayoutPayload(ParseLayoutPayload), RenameLayoutPayload(RenameLayoutPayload), GetLayoutDirPayload(GetLayoutDirPayload), DumpSessionLayoutPayload(DumpSessionLayoutPayload), GetFocusedPaneInfoPayload(GetFocusedPaneInfoPayload), TogglePaneBorderlessPayload(TogglePaneBorderlessPayload), SetPaneBorderlessPayload(SetPaneBorderlessPayload), SaveSessionPayload(SaveSessionPayload), CurrentSessionLastSavedTimePayload(CurrentSessionLastSavedTimePayload), GetPaneInfoPayload(GetPaneInfoPayload), GetTabInfoPayload(GetTabInfoPayload), GetPaneRunningCommandPayload(GetPaneRunningCommandPayload), GetPaneCwdPayload(GetPaneCwdPayload), SwitchTabToIdPayload(SwitchTabToIdPayload), GoToTabWithIdPayload(GoToTabWithIdPayload), CloseTabWithIdPayload(CloseTabWithIdPayload), RenameTabWithIdPayload(RenameTabWithIdPayload), BreakPanesToTabWithIdPayload(BreakPanesToTabWithIdPayload), GetSessionEnvironmentVariablesPayload(GetSessionEnvironmentVariablesPayload), OpenCommandPaneInNewTabPayload(OpenCommandPanePayload), OpenPluginPaneInNewTabPayload(OpenPluginPaneInNewTabPayload), OpenEditorPaneInNewTabPayload(OpenFilePayload), OpenCommandPaneInPlaceOfPaneIdPayload(OpenCommandPaneInPlaceOfPaneIdPayload), OpenTerminalPaneInPlaceOfPaneIdPayload(OpenTerminalPaneInPlaceOfPaneIdPayload), OpenEditPaneInPlaceOfPaneIdPayload(OpenEditPaneInPlaceOfPaneIdPayload), HideFloatingPanesPayload(HideFloatingPanesPayload), ShowFloatingPanesPayload(ShowFloatingPanesPayload), SetPaneColorPayload(SetPaneColorPayload), SetPaneRegexHighlightsPayload(SetPaneRegexHighlightsPayload), ClearPaneHighlightsPayload(ClearPaneHighlightsPayload), OpenPluginPaneFloatingPayload(OpenPluginPaneFloatingPayload), GetSessionListPayload(GetSessionListPayload), KillSessionsAndReplyPayload(KillSessionsPayload), DeleteDeadSessionAndReplyPayload(String),
}

Variants



SubscribePayload(SubscribePayload)



UnsubscribePayload(UnsubscribePayload)



SetSelectablePayload(bool)



OpenFilePayload(OpenFilePayload)



OpenFileFloatingPayload(OpenFilePayload)



OpenTerminalPayload(OpenFilePayload)



OpenTerminalFloatingPayload(OpenFilePayload)



OpenCommandPanePayload(OpenCommandPanePayload)



OpenCommandPaneFloatingPayload(OpenCommandPanePayload)



SwitchTabToPayload(SwitchTabToPayload)



SetTimeoutPayload(SetTimeoutPayload)



ExecCmdPayload(ExecCmdPayload)



PostMessageToPayload(PluginMessagePayload)



PostMessageToPluginPayload(PluginMessagePayload)



ShowSelfPayload(bool)



SwitchToModePayload(SwitchToModePayload)



NewTabsWithLayoutPayload(String)



ResizePayload(ResizePayload)



ResizeWithDirectionPayload(ResizePayload)



MoveFocusPayload(MovePayload)



MoveFocusOrTabPayload(MovePayload)



WritePayload(Vec<u8>)



WriteCharsPayload(String)



MovePaneWithDirectionPayload(MovePayload)



GoToTabNamePayload(String)



FocusOrCreateTabPayload(String)



GoToTabPayload(u32)



StartOrReloadPluginPayload(String)



CloseTerminalPanePayload(u32)



ClosePluginPanePayload(u32)



FocusTerminalPanePayload(PaneIdAndShouldFloat)



FocusPluginPanePayload(PaneIdAndShouldFloat)



RenameTerminalPanePayload(IdAndNewName)



RenamePluginPanePayload(IdAndNewName)



RenameTabPayload(IdAndNewName)



ReportCrashPayload(String)



RequestPluginPermissionPayload(RequestPluginPermissionPayload)



SwitchSessionPayload(SwitchSessionPayload)



OpenFileInPlacePayload(OpenFilePayload)



OpenTerminalInPlacePayload(OpenFilePayload)



OpenCommandPaneInPlacePayload(OpenCommandPanePayload)



RunCommandPayload(RunCommandPayload)



WebRequestPayload(WebRequestPayload)



DeleteDeadSessionPayload(String)



RenameSessionPayload(String)



UnblockCliPipeInputPayload(String)



BlockCliPipeInputPayload(String)



CliPipeOutputPayload(CliPipeOutputPayload)



MessageToPluginPayload(MessageToPluginPayload)



KillSessionsPayload(KillSessionsPayload)



ScanHostFolderPayload(String)



NewTabsWithLayoutInfoPayload(NewTabsWithLayoutInfoPayload)



ReconfigurePayload(ReconfigurePayload)



HidePaneWithIdPayload(HidePaneWithIdPayload)



ShowPaneWithIdPayload(ShowPaneWithIdPayload)



OpenCommandPaneBackgroundPayload(OpenCommandPanePayload)



RerunCommandPanePayload(RerunCommandPanePayload)



ResizePaneIdWithDirectionPayload(ResizePaneIdWithDirectionPayload)



EditScrollbackForPaneWithIdPayload(EditScrollbackForPaneWithIdPayload)



WriteToPaneIdPayload(WriteToPaneIdPayload)



WriteCharsToPaneIdPayload(WriteCharsToPaneIdPayload)



MovePaneWithPaneIdPayload(MovePaneWithPaneIdPayload)



MovePaneWithPaneIdInDirectionPayload(MovePaneWithPaneIdInDirectionPayload)



ClearScreenForPaneIdPayload(ClearScreenForPaneIdPayload)



ScrollUpInPaneIdPayload(ScrollUpInPaneIdPayload)



ScrollDownInPaneIdPayload(ScrollDownInPaneIdPayload)



ScrollToTopInPaneIdPayload(ScrollToTopInPaneIdPayload)



ScrollToBottomInPaneIdPayload(ScrollToBottomInPaneIdPayload)



PageScrollUpInPaneIdPayload(PageScrollUpInPaneIdPayload)



PageScrollDownInPaneIdPayload(PageScrollDownInPaneIdPayload)



TogglePaneIdFullscreenPayload(TogglePaneIdFullscreenPayload)



TogglePaneEmbedOrEjectForPaneIdPayload(TogglePaneEmbedOrEjectForPaneIdPayload)



CloseTabWithIndexPayload(CloseTabWithIndexPayload)



BreakPanesToNewTabPayload(BreakPanesToNewTabPayload)



BreakPanesToTabWithIndexPayload(BreakPanesToTabWithIndexPayload)



ReloadPluginPayload(ReloadPluginPayload)



LoadNewPluginPayload(LoadNewPluginPayload)



RebindKeysPayload(RebindKeysPayload)



ChangeHostFolderPayload(ChangeHostFolderPayload)



SetFloatingPanePinnedPayload(SetFloatingPanePinnedPayload)



StackPanesPayload(StackPanesPayload)



ChangeFloatingPanesCoordinatesPayload(ChangeFloatingPanesCoordinatesPayload)



OpenCommandPaneNearPluginPayload(OpenCommandPaneNearPluginPayload)



OpenTerminalNearPluginPayload(OpenTerminalNearPluginPayload)



OpenTerminalFloatingNearPluginPayload(OpenTerminalFloatingNearPluginPayload)



OpenTerminalInPlaceOfPluginPayload(OpenTerminalInPlaceOfPluginPayload)



OpenCommandPaneFloatingNearPluginPayload(OpenCommandPaneFloatingNearPluginPayload)



OpenCommandPaneInPlaceOfPluginPayload(OpenCommandPaneInPlaceOfPluginPayload)



OpenFileNearPluginPayload(OpenFileNearPluginPayload)



OpenFileFloatingNearPluginPayload(OpenFileFloatingNearPluginPayload)



OpenFileInPlaceOfPluginPayload(OpenFileInPlaceOfPluginPayload)



GroupAndUngroupPanesPayload(GroupAndUngroupPanesPayload)



HighlightAndUnhighlightPanesPayload(HighlightAndUnhighlightPanesPayload)



CloseMultiplePanesPayload(CloseMultiplePanesPayload)



FloatMultiplePanesPayload(FloatMultiplePanesPayload)



EmbedMultiplePanesPayload(EmbedMultiplePanesPayload)



SetSelfMouseSelectionSupportPayload(SetSelfMouseSelectionSupportPayload)



GenerateWebLoginTokenPayload(GenerateWebLoginTokenPayload)



RevokeWebLoginTokenPayload(RevokeWebLoginTokenPayload)



RenameWebLoginTokenPayload(RenameWebLoginTokenPayload)



ReplacePaneWithExistingPanePayload(ReplacePaneWithExistingPanePayload)



NewTabPayload(NewTabPayload)



GetPaneScrollbackPayload(GetPaneScrollbackPayload)



RunActionPayload(RunActionPayload)



ShowCursorPayload(ShowCursorPayload)



CopyToClipboardPayload(CopyToClipboardPayload)



SendSigintToPaneIdPayload(PaneId)



SendSigkillToPaneIdPayload(PaneId)



GetPanePidPayload(GetPanePidPayload)



OverrideLayoutPayload(OverrideLayoutPayload)



SaveLayoutPayload(SaveLayoutPayload)



DeleteLayoutPayload(DeleteLayoutPayload)



EditLayoutPayload(EditLayoutPayload)



GenerateRandomNamePayload(GenerateRandomNamePayload)



DumpLayoutPayload(DumpLayoutPayload)



ParseLayoutPayload(ParseLayoutPayload)



RenameLayoutPayload(RenameLayoutPayload)



GetLayoutDirPayload(GetLayoutDirPayload)



DumpSessionLayoutPayload(DumpSessionLayoutPayload)



GetFocusedPaneInfoPayload(GetFocusedPaneInfoPayload)



TogglePaneBorderlessPayload(TogglePaneBorderlessPayload)



SetPaneBorderlessPayload(SetPaneBorderlessPayload)



SaveSessionPayload(SaveSessionPayload)



CurrentSessionLastSavedTimePayload(CurrentSessionLastSavedTimePayload)



GetPaneInfoPayload(GetPaneInfoPayload)



GetTabInfoPayload(GetTabInfoPayload)



GetPaneRunningCommandPayload(GetPaneRunningCommandPayload)



GetPaneCwdPayload(GetPaneCwdPayload)



SwitchTabToIdPayload(SwitchTabToIdPayload)



GoToTabWithIdPayload(GoToTabWithIdPayload)



CloseTabWithIdPayload(CloseTabWithIdPayload)



RenameTabWithIdPayload(RenameTabWithIdPayload)



BreakPanesToTabWithIdPayload(BreakPanesToTabWithIdPayload)



GetSessionEnvironmentVariablesPayload(GetSessionEnvironmentVariablesPayload)



OpenCommandPaneInNewTabPayload(OpenCommandPanePayload)



OpenPluginPaneInNewTabPayload(OpenPluginPaneInNewTabPayload)



OpenEditorPaneInNewTabPayload(OpenFilePayload)



OpenCommandPaneInPlaceOfPaneIdPayload(OpenCommandPaneInPlaceOfPaneIdPayload)



OpenTerminalPaneInPlaceOfPaneIdPayload(OpenTerminalPaneInPlaceOfPaneIdPayload)



OpenEditPaneInPlaceOfPaneIdPayload(OpenEditPaneInPlaceOfPaneIdPayload)



HideFloatingPanesPayload(HideFloatingPanesPayload)



ShowFloatingPanesPayload(ShowFloatingPanesPayload)



SetPaneColorPayload(SetPaneColorPayload)



SetPaneRegexHighlightsPayload(SetPaneRegexHighlightsPayload)



ClearPaneHighlightsPayload(ClearPaneHighlightsPayload)



OpenPluginPaneFloatingPayload(OpenPluginPaneFloatingPayload)



GetSessionListPayload(GetSessionListPayload)



KillSessionsAndReplyPayload(KillSessionsPayload)



DeleteDeadSessionAndReplyPayload(String)

Implementations

Source

impl Payload

pub fn encode<B>(&self, buf: &mut B)
where B: BufMut,

Encodes the message to a buffer.

pub fn merge<B>( field: &mut Option<Payload>, tag: u32, wire_type: WireType, buf: &mut B, ctx: DecodeContext, ) -> Result<(), DecodeError>
where B: Buf,

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.