pub struct NulError(/* private fields */);Expand description
An error indicating that an interior nul byte was found.
While Rust strings may contain nul bytes in the middle, C strings can’t, as that byte would effectively truncate the string.
This error is created by the new method on
CString. See its documentation for more.
Examples
use std::ffi::{CString, NulError};
let _: NulError = CString::new(b"f\0oo".to_vec()).unwrap_err();Implementations
Sourceimpl NulError
impl NulError
1.0.0 · Sourcepub fn nul_position(&self) -> usize
pub fn nul_position(&self) -> usize
Returns the position of the nul byte in the slice that caused
CString::new to fail.
Examples
use std::ffi::CString;
let nul_error = CString::new("foo\0bar").unwrap_err();
assert_eq!(nul_error.nul_position(), 3);
let nul_error = CString::new("foo bar\0").unwrap_err();
assert_eq!(nul_error.nul_position(), 7);Trait Implementations
impl Eq for NulError
1.0.0 · Sourceimpl Error for NulError
impl Error for NulError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
1.0.0 · Sourceimpl From<NulError> for Error
Available on non-no_global_oom_handling and non-no_rc and non-no_sync only.
impl From<NulError> for Error
Available on non-
no_global_oom_handling and non-no_rc and non-no_sync only.impl StructuralPartialEq for NulError