pub struct FormattingOptions { /* private fields */ }formatting_options)Expand description
Implementations
Sourceimpl FormattingOptions
impl FormattingOptions
Sourcepub const fn new() -> FormattingOptions
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn new() -> FormattingOptions
formatting_options)Construct a new FormattingOptions representing the plain {} formatting specifier:
- no flags,
- filled with spaces,
- no alignment,
- no width,
- no precision, and
- no
DebugAsHexoutput mode.
Sourcepub const fn sign(&mut self, sign: Option<Sign>) -> &mut FormattingOptions
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn sign(&mut self, sign: Option<Sign>) -> &mut FormattingOptions
formatting_options)Sets or removes the sign (the + or the - flag).
+: This is intended for numeric types and indicates that the sign should always be printed. By default only the negative sign of signed values is printed, and the sign of positive or unsigned values is omitted. This flag indicates that the correct sign (+ or -) should always be printed.-: Currently not used
Sourcepub const fn sign_aware_zero_pad(
&mut self,
sign_aware_zero_pad: bool,
) -> &mut FormattingOptions
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn sign_aware_zero_pad( &mut self, sign_aware_zero_pad: bool, ) -> &mut FormattingOptions
formatting_options)Sets or unsets the 0 flag.
This is used to indicate for integer formats that the padding to width should both be done with a 0 character as well as be sign-aware
Sourcepub const fn alternate(&mut self, alternate: bool) -> &mut FormattingOptions
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn alternate(&mut self, alternate: bool) -> &mut FormattingOptions
formatting_options)Sets or unsets the # flag.
This flag indicates that the โalternateโ form of printing should be used. The alternate forms are:
Sourcepub const fn fill(&mut self, fill: char) -> &mut FormattingOptions
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn fill(&mut self, fill: char) -> &mut FormattingOptions
formatting_options)Sets the fill character.
The optional fill character and alignment is provided normally in conjunction with the width parameter. This indicates that if the value being formatted is smaller than width some extra characters will be printed around it.
Sourcepub const fn align(
&mut self,
align: Option<Alignment>,
) -> &mut FormattingOptions
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn align( &mut self, align: Option<Alignment>, ) -> &mut FormattingOptions
formatting_options)Sets or removes the alignment.
The alignment specifies how the value being formatted should be positioned if it is smaller than the width of the formatter.
Sourcepub const fn width(&mut self, width: Option<u16>) -> &mut FormattingOptions
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn width(&mut self, width: Option<u16>) -> &mut FormattingOptions
formatting_options)Sets or removes the width.
This is a parameter for the โminimum widthโ that the format should take
up. If the valueโs string does not fill up this many characters, then
the padding specified by FormattingOptions::fill/FormattingOptions::align
will be used to take up the required space.
Sourcepub const fn precision(
&mut self,
precision: Option<u16>,
) -> &mut FormattingOptions
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn precision( &mut self, precision: Option<u16>, ) -> &mut FormattingOptions
formatting_options)Sets or removes the precision.
- For non-numeric types, this can be considered a โmaximum widthโ. If the resulting string is longer than this width, then it is truncated down to this many characters and that truncated value is emitted with proper fill, alignment and width if those parameters are set.
- For integral types, this is ignored.
- For floating-point types, this indicates how many digits after the decimal point should be printed.
Sourcepub const fn debug_as_hex(
&mut self,
debug_as_hex: Option<DebugAsHex>,
) -> &mut FormattingOptions
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn debug_as_hex( &mut self, debug_as_hex: Option<DebugAsHex>, ) -> &mut FormattingOptions
formatting_options)Specifies whether the Debug trait should use lower-/upper-case
hexadecimal or normal integers
Sourcepub const fn get_sign(&self) -> Option<Sign>
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn get_sign(&self) -> Option<Sign>
formatting_options)Returns the current sign (the + or the - flag).
Sourcepub const fn get_sign_aware_zero_pad(&self) -> bool
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn get_sign_aware_zero_pad(&self) -> bool
formatting_options)Returns the current 0 flag.
Sourcepub const fn get_alternate(&self) -> bool
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn get_alternate(&self) -> bool
formatting_options)Returns the current # flag.
Sourcepub const fn get_fill(&self) -> char
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn get_fill(&self) -> char
formatting_options)Returns the current fill character.
Sourcepub const fn get_align(&self) -> Option<Alignment>
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn get_align(&self) -> Option<Alignment>
formatting_options)Returns the current alignment.
Sourcepub const fn get_width(&self) -> Option<u16>
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn get_width(&self) -> Option<u16>
formatting_options)Returns the current width.
Sourcepub const fn get_precision(&self) -> Option<u16>
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn get_precision(&self) -> Option<u16>
formatting_options)Returns the current precision.
Sourcepub const fn get_debug_as_hex(&self) -> Option<DebugAsHex>
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn get_debug_as_hex(&self) -> Option<DebugAsHex>
formatting_options)Returns the current x? or X? flag.
Sourcepub const fn create_formatter<'a>(
self,
write: &'a mut dyn Write,
) -> Formatter<'a>
๐ฌThis is a nightly-only experimental API. (formatting_options)
pub const fn create_formatter<'a>( self, write: &'a mut dyn Write, ) -> Formatter<'a>
formatting_options)Creates a Formatter that writes its output to the given Write trait.
You may alternatively use Formatter::new().