Module action

Module action 

Structs

AreFloatingPanesVisiblePayload
DumpScreenPayload
EditFilePayload
GoToTabNamePayload
HideFloatingPanesPayload
IdAndName
LaunchOrFocusPluginPayload
MovePanePayload
NewBlockingPanePayload
NewFloatingPanePayload
NewInPlacePanePayload
NewPanePayload
NewPluginPanePayload
NewTabPayload
NewTiledPanePayload
OverrideLayoutPayload
PaneIdAndShouldFloat
ProtobufAction
ProtobufCommandOrPlugin
ProtobufFloatingPaneCoordinates
FloatingPaneCoordinates specifies the position and size of a floating pane
ProtobufFloatingPaneLayout
ProtobufFloatingPlacement
ProtobufInPlaceConfig
ProtobufKeyWithModifier
ProtobufLayoutConstraintFloatingPair
ProtobufLayoutConstraintTiledPair
ProtobufLayoutConstraintWithValue
ProtobufMouseEventPayload
ProtobufNameAndValue
ProtobufNewPanePlacement
NewPanePlacement specifies where a new pane should be placed
ProtobufPaneId
PaneId identifies either a terminal or plugin pane
ProtobufPaneRun
ProtobufPercentOrFixed
ProtobufPluginAlias
ProtobufPluginConfiguration
ProtobufPluginTag
ProtobufPluginUserConfiguration
ProtobufPosition
ProtobufResize
ProtobufRunCommandAction
ProtobufRunEditFileAction
ProtobufRunPlugin
ProtobufRunPluginLocationData
ProtobufRunPluginOrAlias
ProtobufSplitSize
SplitSize represents a dimension that can be either a percentage or fixed size
ProtobufStackedPlacement
ProtobufSwapFloatingLayout
ProtobufSwapTiledLayout
ProtobufTabLayoutInfo
ProtobufTiledPaneLayout
ProtobufTiledPlacement
ScrollAtPayload
SetPaneFrameStylePayload
ShowFloatingPanesPayload
SwitchToModePayload
TabIdAndName
WriteCharsPayload
WritePayload

Enums

CommandOrPluginType
LocationData
OptionalPayload
PluginType
ProtobufActionName
ProtobufBareKey
ProtobufInputMode
ProtobufKeyModifier
ProtobufLayoutConstraint
ProtobufMoveTabDirection
ProtobufPaneFrameStyle
ProtobufResizeDirection
ProtobufRunPluginLocation
ProtobufSearchDirection
ProtobufSearchOption
ProtobufSplitDirection
ProtobufUnblockCondition
UnblockCondition specifies when a blocking pane should unblock
RunType