pub struct ModeUpdatePayload {Show 22 fields
pub current_mode: i32,
pub keybinds: Vec<InputModeKeybinds>,
pub style: Option<Style>,
pub arrow_fonts_support: bool,
pub session_name: Option<String>,
pub base_mode: Option<i32>,
pub editor: Option<String>,
pub shell: Option<String>,
pub web_clients_allowed: Option<bool>,
pub web_sharing: Option<i32>,
pub currently_marking_pane_group: Option<bool>,
pub is_web_client: Option<bool>,
pub web_server_ip: Option<String>,
pub web_server_port: Option<u32>,
pub web_server_capability: Option<bool>,
pub pane_frame_style: Option<i32>,
pub session_dimmed: Option<bool>,
pub ancestry: Vec<String>,
pub host_fullscreen: Option<bool>,
pub nested_ascend_keys: Vec<String>,
pub session_ascended: Option<bool>,
pub nested_descend_keys: Vec<String>,
}Fields
current_mode: i32keybinds: Vec<InputModeKeybinds>style: Option<Style>arrow_fonts_support: boolsession_name: Option<String>base_mode: Option<i32>editor: Option<String>shell: Option<String>web_clients_allowed: Option<bool>web_sharing: Option<i32>currently_marking_pane_group: Option<bool>is_web_client: Option<bool>web_server_ip: Option<String>web_server_port: Option<u32>web_server_capability: Option<bool>pane_frame_style: Option<i32>session_dimmed: Option<bool>ancestry: Vec<String>host_fullscreen: Option<bool>nested_ascend_keys: Vec<String>session_ascended: Option<bool>nested_descend_keys: Vec<String>Implementations
Sourceimpl ModeUpdatePayload
impl ModeUpdatePayload
Sourcepub fn current_mode(&self) -> InputMode
pub fn current_mode(&self) -> InputMode
Returns the enum value of current_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_current_mode(&mut self, value: InputMode)
pub fn set_current_mode(&mut self, value: InputMode)
Sets current_mode to the provided enum value.
Sourcepub fn session_name(&self) -> &str
pub fn session_name(&self) -> &str
Returns the value of session_name, or the default value if session_name is unset.
Sourcepub fn base_mode(&self) -> InputMode
pub fn base_mode(&self) -> InputMode
Returns the enum value of base_mode, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_base_mode(&mut self, value: InputMode)
pub fn set_base_mode(&mut self, value: InputMode)
Sets base_mode to the provided enum value.
Sourcepub fn editor(&self) -> &str
pub fn editor(&self) -> &str
Returns the value of editor, or the default value if editor is unset.
Sourcepub fn shell(&self) -> &str
pub fn shell(&self) -> &str
Returns the value of shell, or the default value if shell is unset.
Sourcepub fn web_clients_allowed(&self) -> bool
pub fn web_clients_allowed(&self) -> bool
Returns the value of web_clients_allowed, or the default value if web_clients_allowed is unset.
Sourcepub fn web_sharing(&self) -> WebSharing
pub fn web_sharing(&self) -> WebSharing
Returns the enum value of web_sharing, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_web_sharing(&mut self, value: WebSharing)
pub fn set_web_sharing(&mut self, value: WebSharing)
Sets web_sharing to the provided enum value.
Sourcepub fn currently_marking_pane_group(&self) -> bool
pub fn currently_marking_pane_group(&self) -> bool
Returns the value of currently_marking_pane_group, or the default value if currently_marking_pane_group is unset.
Sourcepub fn is_web_client(&self) -> bool
pub fn is_web_client(&self) -> bool
Returns the value of is_web_client, or the default value if is_web_client is unset.
Sourcepub fn web_server_ip(&self) -> &str
pub fn web_server_ip(&self) -> &str
Returns the value of web_server_ip, or the default value if web_server_ip is unset.
Sourcepub fn web_server_port(&self) -> u32
pub fn web_server_port(&self) -> u32
Returns the value of web_server_port, or the default value if web_server_port is unset.
Sourcepub fn web_server_capability(&self) -> bool
pub fn web_server_capability(&self) -> bool
Returns the value of web_server_capability, or the default value if web_server_capability is unset.
Sourcepub fn pane_frame_style(&self) -> PaneFrameStyle
pub fn pane_frame_style(&self) -> PaneFrameStyle
Returns the enum value of pane_frame_style, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_pane_frame_style(&mut self, value: PaneFrameStyle)
pub fn set_pane_frame_style(&mut self, value: PaneFrameStyle)
Sets pane_frame_style to the provided enum value.
Sourcepub fn session_dimmed(&self) -> bool
pub fn session_dimmed(&self) -> bool
Returns the value of session_dimmed, or the default value if session_dimmed is unset.
Sourcepub fn host_fullscreen(&self) -> bool
pub fn host_fullscreen(&self) -> bool
Returns the value of host_fullscreen, or the default value if host_fullscreen is unset.
Sourcepub fn session_ascended(&self) -> bool
pub fn session_ascended(&self) -> bool
Returns the value of session_ascended, or the default value if session_ascended is unset.