Message

Trait Message 

pub trait Message:
    Debug
    + Send
    + Sync {
    // Required methods
    fn encoded_len(&self) -> usize;
    fn clear(&mut self);

    // Provided methods
    fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
       where B: BufMut,
             Self: Sized { ... }
    fn encode_to_vec(&self) -> Vec<u8> 
       where Self: Sized { ... }
    fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
       where B: BufMut,
             Self: Sized { ... }
    fn encode_length_delimited_to_vec(&self) -> Vec<u8> 
       where Self: Sized { ... }
    fn decode<B>(buf: B) -> Result<Self, DecodeError>
       where B: Buf,
             Self: Default { ... }
    fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
       where B: Buf,
             Self: Default { ... }
    fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
       where B: Buf,
             Self: Sized { ... }
    fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
       where B: Buf,
             Self: Sized { ... }
}
A Protocol Buffers message.

Required Methods

fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.

fn clear(&mut self)

Clears the message, resetting all fields to their default.

Provided Methods

fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
where B: BufMut, Self: Sized,

Encodes the message to a buffer.

An error will be returned if the buffer does not have sufficient capacity.

fn encode_to_vec(&self) -> Vec<u8>
where Self: Sized,

Encodes the message to a newly allocated buffer.

fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
where B: BufMut, Self: Sized,

Encodes the message with a length-delimiter to a buffer.

An error will be returned if the buffer does not have sufficient capacity.

fn encode_length_delimited_to_vec(&self) -> Vec<u8>
where Self: Sized,

Encodes the message with a length-delimiter to a newly allocated buffer.

fn decode<B>(buf: B) -> Result<Self, DecodeError>
where B: Buf, Self: Default,

Decodes an instance of the message from a buffer.

The entire buffer will be consumed.

fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
where B: Buf, Self: Default,

Decodes a length-delimited instance of the message from the buffer.

fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
where B: Buf, Self: Sized,

Decodes an instance of the message from a buffer, and merges it into self.

The entire buffer will be consumed.

fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
where B: Buf, Self: Sized,

Decodes a length-delimited instance of the message from buffer, and merges it into self.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Message for ()

google.protobuf.Empty

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for Action

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ActionMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for AncestryUpdate

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for Announce

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for AnnounceAck

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for AreFloatingPanesVisibleAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for AttachClientMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for AttachWatcherClientMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for BackgroundColorMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for BreakPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for BreakPaneLeftAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for BreakPaneRightAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for Bye

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ChangeFloatingPaneCoordinatesAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CharKey

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ClearScreenAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ClearScreenByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CliAssets

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CliPipeAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CliPipeOutputMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ClientExitedMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ClientToServerMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CloseFocusAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CloseFocusByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ClosePluginPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CloseTabAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CloseTabByIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CloseTerminalPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ColorRegister

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ColorRegistersMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CommandOrPlugin

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CommandOrPluginFile

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ConfigFileUpdatedMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ConfirmAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ConnStatusMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ConnectToSession

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ConnectedMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CopyAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CopyLastCommandOutputAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for CurrentTabInfoAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for DenyAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for DesktopNotificationResponseMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for DetachAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for DetachSessionMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for DumpLayoutAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for DumpScreenAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for EditFileAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for EditScrollbackAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for EditScrollbackByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for EmitNestedSessionFrameMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ExitMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FailedToStartWebServerMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FirstClientConnectedMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FloatingCoordinate

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FloatingPaneCoordinates

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FloatingPaneLayout

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FocusGained

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FocusGuestSessionAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FocusHost

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FocusHostSessionAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FocusLastPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FocusLost

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FocusNextPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FocusPaneByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FocusPluginPaneWithIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FocusPreviousPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FocusTerminalPaneWithIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ForegroundColorMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ForwardQueryToHostMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ForwardedReplyFromHostMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FullscreenState

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for FunctionKey

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for GoToNextTabAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for GoToPreviousTabAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for GoToTabAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for GoToTabByIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for GoToTabNameAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for HalfPageScrollDownAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for HalfPageScrollDownByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for HalfPageScrollUpAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for HalfPageScrollUpByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for HideFloatingPanesAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for HostTerminalFocusChangedMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for HostTerminalThemeChangedMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for KeyMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for KeyWithModifier

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for KeybindPipeAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for KillSessionMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for KittyGraphicsSupportMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for LaunchOrFocusPluginAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for LaunchPluginAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for LayoutConstraintFloatingPair

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for LayoutConstraintTiledPair

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for LayoutConstraintWithValue

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for LayoutInfo

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for LayoutMetadata

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ListClientsAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ListPanesAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ListTabsAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for LogErrorMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for LogMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MobileActivePaneMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MobilePaneMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MobileRenderPrefsMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MobileSessionMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MobileSizeMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MobileStateMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MobileTabMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MouseEvent

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MouseEventAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MoveFocusAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MoveFocusOrTabAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MovePaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MovePaneBackwardsAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MovePaneBackwardsByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MovePaneByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MoveTabAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for MoveTabByTabIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NestedSessionFrameFromHostMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NestedSessionMessage

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NewBlockingPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NewFloatingPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NewFloatingPluginPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NewInPlacePaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NewInPlacePluginPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NewPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NewPanePlacement

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NewPanePlacementInPlace

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NewStackedPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NewTabAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NewTiledPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NewTiledPluginPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NextSwapLayoutAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NextSwapLayoutByTabIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NoOpAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for NoPreferencePlacement

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for OpenFilePayload

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for Options

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for OriginatingPlugin

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for OverrideLayoutAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PageScrollDownAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PageScrollDownByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PageScrollUpAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PageScrollUpByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PaletteColor

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PaneId

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PaneIdWithPlugin

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PaneMetadata

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PaneNameInputAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PaneReference

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PaneRenderUpdateMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PasteAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PercentOrFixed

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for Ping

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PixelDimensions

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PluginAlias

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PluginTag

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PluginUserConfiguration

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for Pong

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for Position

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PreviousSwapLayoutAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for PreviousSwapLayoutByTabIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for QueryTabNamesAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for QueryTerminalSizeMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for QuitAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RenamePaneByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RenamePluginPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RenameSessionAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RenameTabAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RenameTabByIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RenameTerminalPaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RenamedSessionMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RenderMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RequestSessionListMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ResizeAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ResizeByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RgbColor

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for Run

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RunAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RunCommandAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RunEditFileAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RunPlugin

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RunPluginLocationData

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for RunPluginOrAlias

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SaveSessionAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ScrollDownAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ScrollDownAtAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ScrollDownByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ScrollToBottomAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ScrollToBottomByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ScrollToNextPromptAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ScrollToPreviousPromptAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ScrollToTopAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ScrollToTopByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ScrollUpAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ScrollUpAtAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ScrollUpByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SearchAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SearchInputAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SearchToggleOptionAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SelectCommandAtScrollPositionAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ServerToClientMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SetDarkThemeAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SetLightThemeAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SetMobileRenderPreferencesMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SetPaneBorderlessAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SetPaneColorAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SetPaneFrameStyleAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SetSoftKeyboardMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ShortcutUpdate

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ShowFloatingPanesAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SixelSupportMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for Size

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SizeInPixels

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SkipConfirmAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SoftKeyboardVisibilityChangedMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SplitSize

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for StackPanesAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for StackedPlacement

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for StartOrReloadPluginAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for StartWebServerMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for Style

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for Styling

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SubscribeToPaneRendersMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SubscribedPaneClosedMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SwapFloatingLayout

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SwapTiledLayout

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SwitchFocusAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SwitchModeForAllClientsAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SwitchSessionAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SwitchSessionMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for SwitchToModeAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TabLayoutInfo

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TabMetadata

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TabNameInputAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TerminalPixelDimensionsMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TerminalResizeMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TiledPaneLayout

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TiledPlacement

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleActiveSyncTabAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleActiveSyncTabByTabIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleFloatingPanesAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleFloatingPanesByTabIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleFocusFullscreenAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleFocusNoUiFullscreenAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleFullscreenByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleGroupMarkingAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleHostFullscreen

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleHostFullscreenAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleMouseModeAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleNoUiFullscreenByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TogglePaneBorderlessAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TogglePaneEmbedOrFloatingAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TogglePaneEmbedOrFloatingByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TogglePaneFramesAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TogglePaneInGroupAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TogglePanePinnedAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for TogglePanePinnedByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleTabAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for ToggleThemeAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for UnblockCliPipeInputMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for UnblockInputThreadMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for UndoRenamePaneAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for UndoRenamePaneByPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for UndoRenameTabAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for UndoRenameTabByTabIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for WebServerStartedMsg

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for WriteAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for WriteCharsAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for WriteCharsToPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for WriteToPaneIdAction

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for bool

google.protobuf.BoolValue

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for f32

google.protobuf.FloatValue

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for f64

google.protobuf.DoubleValue

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for i32

google.protobuf.Int32Value

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for i64

google.protobuf.Int64Value

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for u32

google.protobuf.UInt32Value

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Source

impl Message for u64

google.protobuf.UInt64Value

Source

fn encoded_len(&self) -> usize

Source

fn clear(&mut self)

Implementors

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufAction

Source

impl Message for ActionCompletePayload

Source

impl Message for ActivePaneScrollPayload

Source

impl Message for AreFloatingPanesVisiblePayload

Source

impl Message for Arg

Source

impl Message for AvailableLayoutInfoPayload

Source

impl Message for BreakPanesToNewTabPayload

Source

impl Message for BreakPanesToNewTabResponse

Source

impl Message for BreakPanesToTabWithIdPayload

Source

impl Message for BreakPanesToTabWithIdResponse

Source

impl Message for BreakPanesToTabWithIndexPayload

Source

impl Message for BreakPanesToTabWithIndexResponse

Source

impl Message for Bytes

google.protobuf.BytesValue

Source

impl Message for ChangeFloatingPanesCoordinatesPayload

Source

impl Message for ChangeHostFolderPayload

Source

impl Message for ClearPaneHighlightsPayload

Source

impl Message for ClearScreenForPaneIdPayload

Source

impl Message for CliPipeOutputPayload

Source

impl Message for CliPipePayload

Source

impl Message for ClientInfo

Source

impl Message for ClientPaneHistory

Source

impl Message for ClientTabHistory

Source

impl Message for CloseMultiplePanesPayload

Source

impl Message for CloseTabWithIdPayload

Source

impl Message for CloseTabWithIndexPayload

Source

impl Message for Color

Source

impl Message for Command

Source

impl Message for CommandChangedPayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufCommandOrPlugin

Source

impl Message for zellij_tile::shim::plugin_api::generated_api::api::action::CommandOrPluginFile

Source

impl Message for CommandPaneExitedPayload

Source

impl Message for CommandPaneOpenedPayload

Source

impl Message for CommandPaneReRunPayload

Source

impl Message for zellij_tile::shim::plugin_api::event::ProtobufContextItem

Source

impl Message for zellij_tile::shim::plugin_api::plugin_command::ContextItem

Source

impl Message for CopyToClipboardPayload

Source

impl Message for CreateTokenResponse

Source

impl Message for CurrentSessionLastSavedTimePayload

Source

impl Message for CurrentSessionLastSavedTimeResponse

Source

impl Message for CursorPosition

Source

impl Message for CustomIndexHighlight

Source

impl Message for CustomMessagePayload

Source

impl Message for CustomRgbHighlight

Source

impl Message for CwdChangedPayload

Source

impl Message for DeleteAllDeadSessionsResponse

Source

impl Message for DeleteDeadSessionResponse

Source

impl Message for DeleteLayoutPayload

Source

impl Message for DeleteLayoutResponse

Source

impl Message for DumpLayoutPayload

Source

impl Message for DumpLayoutResponse

Source

impl Message for DumpScreenPayload

Source

impl Message for DumpSessionLayoutPayload

Source

impl Message for DumpSessionLayoutResponse

Source

impl Message for EditFilePayload

Source

impl Message for EditLayoutPayload

Source

impl Message for EditLayoutResponse

Source

impl Message for EditPaneExitedPayload

Source

impl Message for EditPaneOpenedPayload

Source

impl Message for EditScrollbackForPaneWithIdPayload

Source

impl Message for EmbedMultiplePanesPayload

Source

impl Message for EnvVariable

Source

impl Message for Event

Source

impl Message for EventNameList

Source

impl Message for ExecCmdPayload

Source

impl Message for FailedToChangeHostFolderPayload

Source

impl Message for FailedToStartWebServerPayload

Source

impl Message for FailedToWriteConfigToDiskPayload

Source

impl Message for File

Source

impl Message for FileListPayload

Source

impl Message for FileMetadata

Source

impl Message for FixedOrPercentValue

Source

impl Message for FloatMultiplePanesPayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufFloatingPaneCoordinates

Source

impl Message for zellij_tile::shim::plugin_api::plugin_command::ProtobufFloatingPaneCoordinates

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufFloatingPaneLayout

Source

impl Message for FloatingPlacement

Source

impl Message for FocusOrCreateTabResponse

Source

impl Message for FocusedPaneInfo

Source

impl Message for GenerateRandomNamePayload

Source

impl Message for GenerateRandomNameResponse

Source

impl Message for GenerateWebLoginTokenPayload

Source

impl Message for GetFocusedPaneInfoPayload

Source

impl Message for GetFocusedPaneInfoResponse

Source

impl Message for GetLayoutDirPayload

Source

impl Message for GetLayoutDirResponse

Source

impl Message for GetPaneCwdPayload

Source

impl Message for GetPaneCwdResponse

Source

impl Message for GetPaneInfoPayload

Source

impl Message for GetPaneInfoResponse

Source

impl Message for GetPanePidPayload

Source

impl Message for GetPanePidResponse

Source

impl Message for GetPaneRunningCommandPayload

Source

impl Message for GetPaneRunningCommandResponse

Source

impl Message for GetPaneScrollbackPayload

Source

impl Message for GetSessionEnvironmentVariablesPayload

Source

impl Message for GetSessionEnvironmentVariablesResponse

Source

impl Message for GetSessionListPayload

Source

impl Message for GetSessionListResponse

Source

impl Message for GetTabInfoPayload

Source

impl Message for GetTabInfoResponse

Source

impl Message for GoToTabNamePayload

Source

impl Message for GoToTabWithIdPayload

Source

impl Message for GroupAndUngroupPanesPayload

Source

impl Message for Header

Source

impl Message for zellij_tile::shim::plugin_api::action::HideFloatingPanesPayload

Source

impl Message for zellij_tile::shim::plugin_api::plugin_command::ProtobufHideFloatingPanesPayload

Source

impl Message for HideFloatingPanesResponse

Source

impl Message for HidePaneWithIdPayload

Source

impl Message for HighlightAndUnhighlightPanesPayload

Source

impl Message for HighlightClickedPayload

Source

impl Message for HighlightStyle

Source

impl Message for HintTextPayload

Source

impl Message for HostFolderChangedPayload

Source

impl Message for HostTerminalThemeChangedPayload

Source

impl Message for IdAndName

Source

impl Message for IdAndNewName

Source

impl Message for InPlaceConfig

Source

impl Message for IndexInPaneGroup

Source

impl Message for InitialKeybindsPayload

Source

impl Message for InputModeKeybinds

Source

impl Message for InputModeMessage

Source

impl Message for KdlError

Source

impl Message for KdlErrorVariant

Source

impl Message for Key

Source

impl Message for KeyBind

Source

impl Message for KeyToRebind

Source

impl Message for KeyToUnbind

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufKeyWithModifier

Source

impl Message for KillSessionsPayload

Source

impl Message for KillSessionsResponse

Source

impl Message for LaunchOrFocusPluginPayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufLayoutConstraintFloatingPair

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufLayoutConstraintTiledPair

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufLayoutConstraintWithValue

Source

impl Message for zellij_tile::shim::plugin_api::event::ProtobufLayoutInfo

Source

impl Message for zellij_tile::shim::plugin_api::event::ProtobufLayoutMetadata

Source

impl Message for LayoutParsingError

Source

impl Message for LayoutWithError

Source

impl Message for ListClientsPayload

Source

impl Message for ListTokensResponse

Source

impl Message for LoadNewPluginPayload

Source

impl Message for Message

Source

impl Message for MessageToPluginPayload

Source

impl Message for ModeUpdatePayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufMouseEventPayload

Source

impl Message for zellij_tile::shim::plugin_api::event::MouseEventPayload

Source

impl Message for MoveDirection

Source

impl Message for MovePanePayload

Source

impl Message for MovePaneWithPaneIdInDirectionPayload

Source

impl Message for MovePaneWithPaneIdPayload

Source

impl Message for MovePayload

Source

impl Message for NameAndValue

Source

impl Message for NewBlockingPanePayload

Source

impl Message for NewFloatingPanePayload

Source

impl Message for NewInPlacePanePayload

Source

impl Message for NewPanePayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufNewPanePlacement

Source

impl Message for NewPluginArgs

Source

impl Message for NewPluginPanePayload

Source

impl Message for zellij_tile::shim::plugin_api::action::NewTabPayload

Source

impl Message for zellij_tile::shim::plugin_api::plugin_command::NewTabPayload

Source

impl Message for NewTabResponse

Source

impl Message for NewTabUnfocusedPayload

Source

impl Message for NewTabUnfocusedResponse

Source

impl Message for NewTabsResponse

Source

impl Message for NewTabsWithLayoutInfoPayload

Source

impl Message for NewTiledPaneInTabPayload

Source

impl Message for NewTiledPaneInTabResponse

Source

impl Message for NewTiledPanePayload

Source

impl Message for NoPreferenceOptions

Source

impl Message for OpenCommandPaneBackgroundResponse

Source

impl Message for OpenCommandPaneFloatingNearPluginPayload

Source

impl Message for OpenCommandPaneFloatingNearPluginResponse

Source

impl Message for OpenCommandPaneFloatingResponse

Source

impl Message for OpenCommandPaneInPlaceOfPaneIdPayload

Source

impl Message for OpenCommandPaneInPlaceOfPaneIdResponse

Source

impl Message for OpenCommandPaneInPlaceOfPluginPayload

Source

impl Message for OpenCommandPaneInPlaceOfPluginResponse

Source

impl Message for OpenCommandPaneInPlaceResponse

Source

impl Message for OpenCommandPaneNearPluginPayload

Source

impl Message for OpenCommandPaneNearPluginResponse

Source

impl Message for OpenCommandPanePayload

Source

impl Message for OpenCommandPaneResponse

Source

impl Message for OpenEditPaneInPlaceOfPaneIdPayload

Source

impl Message for OpenEditPaneInPlaceOfPaneIdResponse

Source

impl Message for OpenFileFloatingNearPluginPayload

Source

impl Message for OpenFileFloatingNearPluginResponse

Source

impl Message for OpenFileFloatingResponse

Source

impl Message for OpenFileInPlaceOfPluginPayload

Source

impl Message for OpenFileInPlaceOfPluginResponse

Source

impl Message for OpenFileInPlaceResponse

Source

impl Message for OpenFileNearPluginPayload

Source

impl Message for OpenFileNearPluginResponse

Source

impl Message for zellij_tile::shim::plugin_api::plugin_command::OpenFilePayload

Source

impl Message for OpenFileResponse

Source

impl Message for OpenPaneInNewTabResponse

Source

impl Message for OpenPluginPaneFloatingPayload

Source

impl Message for OpenPluginPaneFloatingResponse

Source

impl Message for OpenPluginPaneInNewTabPayload

Source

impl Message for OpenTerminalFloatingNearPluginPayload

Source

impl Message for OpenTerminalFloatingNearPluginResponse

Source

impl Message for OpenTerminalFloatingResponse

Source

impl Message for OpenTerminalInPlaceOfPluginPayload

Source

impl Message for OpenTerminalInPlaceOfPluginResponse

Source

impl Message for OpenTerminalInPlaceResponse

Source

impl Message for OpenTerminalNearPluginPayload

Source

impl Message for OpenTerminalNearPluginResponse

Source

impl Message for OpenTerminalPaneInPlaceOfPaneIdPayload

Source

impl Message for OpenTerminalPaneInPlaceOfPaneIdResponse

Source

impl Message for OpenTerminalResponse

Source

impl Message for zellij_tile::shim::plugin_api::action::OverrideLayoutPayload

Source

impl Message for zellij_tile::shim::plugin_api::plugin_command::OverrideLayoutPayload

Source

impl Message for PageScrollDownInPaneIdPayload

Source

impl Message for PageScrollUpInPaneIdPayload

Source

impl Message for Palette

Source

impl Message for PaneClosedPayload

Source

impl Message for PaneContents

Source

impl Message for PaneContentsEntry

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufPaneId

Source

impl Message for zellij_tile::shim::plugin_api::event::ProtobufPaneId

Source

impl Message for zellij_tile::shim::plugin_api::plugin_command::ProtobufPaneId

Source

impl Message for PaneIdAndFloatingPaneCoordinates

Source

impl Message for PaneIdAndShouldFloat

Source

impl Message for PaneInfo

Source

impl Message for PaneManifest

Source

impl Message for zellij_tile::shim::plugin_api::event::ProtobufPaneMetadata

Source

impl Message for PaneRenderReportPayload

Source

impl Message for PaneRun

Source

impl Message for PaneScrollbackResponse

Source

impl Message for PaneUpdatePayload

Source

impl Message for ParseLayoutPayload

Source

impl Message for ParseLayoutResponse

Source

impl Message for PastedTextPayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufPercentOrFixed

Source

impl Message for PermissionRequestResultPayload

Source

impl Message for PipeMessage

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufPluginAlias

Source

impl Message for PluginCommand

Source

impl Message for PluginConfiguration

Source

impl Message for PluginConfigurationChangedPayload

Source

impl Message for PluginIds

Source

impl Message for PluginInfo

Source

impl Message for PluginMessagePayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufPluginTag

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufPluginUserConfiguration

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufPosition

Source

impl Message for RebindKeysPayload

Source

impl Message for ReconfigurePayload

Source

impl Message for RegexHighlight

Source

impl Message for ReloadPluginPayload

Source

impl Message for RenameLayoutPayload

Source

impl Message for RenameLayoutResponse

Source

impl Message for RenameTabWithIdPayload

Source

impl Message for RenameWebLoginTokenPayload

Source

impl Message for RenameWebTokenResponse

Source

impl Message for ReplacePaneWithExistingPanePayload

Source

impl Message for RequestPluginPermissionPayload

Source

impl Message for RerunCommandPanePayload

Source

impl Message for Resize

Source

impl Message for ResizePaneIdWithDirectionPayload

Source

impl Message for ResizePayload

Source

impl Message for ResurrectableSession

Source

impl Message for RevokeAllWebTokensResponse

Source

impl Message for RevokeTokenResponse

Source

impl Message for RevokeWebLoginTokenPayload

Source

impl Message for RgbColorPayload

Source

impl Message for RunActionPayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufRunCommandAction

Source

impl Message for RunCommandPayload

Source

impl Message for RunCommandResultPayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufRunEditFileAction

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufRunPlugin

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufRunPluginLocationData

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufRunPluginOrAlias

Source

impl Message for RunningCommand

Source

impl Message for SaveLayoutPayload

Source

impl Message for SaveLayoutResponse

Source

impl Message for SaveSessionPayload

Source

impl Message for SaveSessionResponse

Source

impl Message for ScrollAtPayload

Source

impl Message for ScrollDownInPaneIdPayload

Source

impl Message for ScrollToBottomInPaneIdPayload

Source

impl Message for ScrollToTopInPaneIdPayload

Source

impl Message for ScrollUpInPaneIdPayload

Source

impl Message for SelectedText

Source

impl Message for SessionListSnapshot

Source

impl Message for SessionManifest

Source

impl Message for SessionUpdatePayload

Source

impl Message for SetFloatingPanePinnedPayload

Source

impl Message for zellij_tile::shim::plugin_api::generated_api::api::action::SetPaneBorderlessPayload

Source

impl Message for zellij_tile::shim::plugin_api::plugin_command::SetPaneBorderlessPayload

Source

impl Message for SetPaneColorPayload

Source

impl Message for zellij_tile::shim::plugin_api::action::SetPaneFrameStylePayload

Source

impl Message for zellij_tile::shim::plugin_api::plugin_command::ProtobufSetPaneFrameStylePayload

Source

impl Message for SetPaneRegexHighlightsPayload

Source

impl Message for SetSelfMouseSelectionSupportPayload

Source

impl Message for SetSoftKeyboardPayload

Source

impl Message for SetTimeoutPayload

Source

impl Message for ShowCursorPayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ShowFloatingPanesPayload

Source

impl Message for zellij_tile::shim::plugin_api::plugin_command::ProtobufShowFloatingPanesPayload

Source

impl Message for ShowFloatingPanesResponse

Source

impl Message for ShowPaneWithIdPayload

Source

impl Message for SoftKeyboardVisibilityChangedPayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufSplitSize

Source

impl Message for StackPanesPayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufStackedPlacement

Source

impl Message for String

google.protobuf.StringValue

Source

impl Message for zellij_tile::shim::plugin_api::event::ProtobufStyle

Source

impl Message for StyledText

Source

impl Message for StyledTextIndices

Source

impl Message for zellij_tile::shim::plugin_api::generated_api::api::style::Styling

Source

impl Message for SubscribePayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufSwapFloatingLayout

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufSwapTiledLayout

Source

impl Message for SwitchSessionPayload

Source

impl Message for SwitchTabToIdPayload

Source

impl Message for SwitchTabToPayload

Source

impl Message for SwitchToModePayload

Source

impl Message for SyntaxError

Source

impl Message for TabIdAndName

Source

impl Message for TabInfo

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufTabLayoutInfo

Source

impl Message for zellij_tile::shim::plugin_api::event::ProtobufTabMetadata

Source

impl Message for TabUpdatePayload

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufTiledPaneLayout

Source

impl Message for zellij_tile::shim::plugin_api::action::ProtobufTiledPlacement

Source

impl Message for ToggleFloatingPanesPayload

Source

impl Message for TogglePaneBorderlessPayload

Source

impl Message for TogglePaneEmbedOrEjectForPaneIdPayload

Source

impl Message for TogglePaneIdFullscreenPayload

Source

impl Message for UnsubscribePayload

Source

impl Message for UserActionPayload

Source

impl Message for Vec<u8>

google.protobuf.BytesValue

Source

impl Message for WebRequestPayload

Source

impl Message for WebRequestResultPayload

Source

impl Message for WebServerStatusPayload

Source

impl Message for WriteCharsPayload

Source

impl Message for WriteCharsToPaneIdPayload

Source

impl Message for WritePayload

Source

impl Message for WriteToPaneIdPayload

Source

impl Message for ZellijVersion

Source

impl<M> Message for Box<M>
where M: Message,