pub struct Limit<T> { /* private fields */ }Expand description
A BufMut adapter which limits the amount of bytes that can be written
to an underlying buffer.
Implementations
Sourceimpl<T> Limit<T>
impl<T> Limit<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes this Limit, returning the underlying value.
Sourcepub fn get_ref(&self) -> &T
pub fn get_ref(&self) -> &T
Gets a reference to the underlying BufMut.
It is inadvisable to directly write to the underlying BufMut.
Sourcepub fn get_mut(&mut self) -> &mut T
pub fn get_mut(&mut self) -> &mut T
Gets a mutable reference to the underlying BufMut.
It is inadvisable to directly write to the underlying BufMut.