pub trait Message:
Debug
+ Send
+ Sync {
// Required methods
fn encoded_len(&self) -> usize;
fn clear(&mut self);
// Provided methods
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
where B: BufMut,
Self: Sized { ... }
fn encode_to_vec(&self) -> Vec<u8> ⓘ
where Self: Sized { ... }
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
where B: BufMut,
Self: Sized { ... }
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘ
where Self: Sized { ... }
fn decode<B>(buf: B) -> Result<Self, DecodeError>
where B: Buf,
Self: Default { ... }
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
where B: Buf,
Self: Default { ... }
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
where B: Buf,
Self: Sized { ... }
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
where B: Buf,
Self: Sized { ... }
}Expand description
A Protocol Buffers message.
Required Methods
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Provided Methods
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer.
An error will be returned if the buffer does not have sufficient capacity.
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer.
An error will be returned if the buffer does not have sufficient capacity.
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer.
The entire buffer will be consumed.
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
The entire buffer will be consumed.
Sourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into self.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl Message for AncestryUpdate
impl Message for AncestryUpdate
Sourceimpl Message for AttachClientMsg
impl Message for AttachClientMsg
Sourceimpl Message for AttachWatcherClientMsg
impl Message for AttachWatcherClientMsg
Sourceimpl Message for BackgroundColorMsg
impl Message for BackgroundColorMsg
Sourceimpl Message for BreakPaneAction
impl Message for BreakPaneAction
Sourceimpl Message for BreakPaneLeftAction
impl Message for BreakPaneLeftAction
Sourceimpl Message for BreakPaneRightAction
impl Message for BreakPaneRightAction
Sourceimpl Message for ClearScreenAction
impl Message for ClearScreenAction
Sourceimpl Message for ClearScreenByPaneIdAction
impl Message for ClearScreenByPaneIdAction
Sourceimpl Message for CliPipeAction
impl Message for CliPipeAction
Sourceimpl Message for CliPipeOutputMsg
impl Message for CliPipeOutputMsg
Sourceimpl Message for ClientExitedMsg
impl Message for ClientExitedMsg
Sourceimpl Message for ClientToServerMsg
impl Message for ClientToServerMsg
Sourceimpl Message for CloseFocusAction
impl Message for CloseFocusAction
Sourceimpl Message for CloseFocusByPaneIdAction
impl Message for CloseFocusByPaneIdAction
Sourceimpl Message for ClosePluginPaneAction
impl Message for ClosePluginPaneAction
Sourceimpl Message for CloseTabAction
impl Message for CloseTabAction
Sourceimpl Message for CloseTabByIdAction
impl Message for CloseTabByIdAction
Sourceimpl Message for CloseTerminalPaneAction
impl Message for CloseTerminalPaneAction
Sourceimpl Message for ColorRegister
impl Message for ColorRegister
Sourceimpl Message for ColorRegistersMsg
impl Message for ColorRegistersMsg
Sourceimpl Message for CommandOrPlugin
impl Message for CommandOrPlugin
Sourceimpl Message for CommandOrPluginFile
impl Message for CommandOrPluginFile
Sourceimpl Message for ConfigFileUpdatedMsg
impl Message for ConfigFileUpdatedMsg
Sourceimpl Message for ConfirmAction
impl Message for ConfirmAction
Sourceimpl Message for ConnStatusMsg
impl Message for ConnStatusMsg
Sourceimpl Message for ConnectToSession
impl Message for ConnectToSession
Sourceimpl Message for CurrentTabInfoAction
impl Message for CurrentTabInfoAction
Sourceimpl Message for DetachSessionMsg
impl Message for DetachSessionMsg
Sourceimpl Message for DumpLayoutAction
impl Message for DumpLayoutAction
Sourceimpl Message for DumpScreenAction
impl Message for DumpScreenAction
Sourceimpl Message for EditFileAction
impl Message for EditFileAction
Sourceimpl Message for EditScrollbackAction
impl Message for EditScrollbackAction
Sourceimpl Message for EmitNestedSessionFrameMsg
impl Message for EmitNestedSessionFrameMsg
Sourceimpl Message for FailedToStartWebServerMsg
impl Message for FailedToStartWebServerMsg
Sourceimpl Message for FirstClientConnectedMsg
impl Message for FirstClientConnectedMsg
Sourceimpl Message for FloatingCoordinate
impl Message for FloatingCoordinate
Sourceimpl Message for FloatingPaneCoordinates
impl Message for FloatingPaneCoordinates
Sourceimpl Message for FloatingPaneLayout
impl Message for FloatingPaneLayout
Sourceimpl Message for FocusGuestSessionAction
impl Message for FocusGuestSessionAction
Sourceimpl Message for FocusHostSessionAction
impl Message for FocusHostSessionAction
Sourceimpl Message for FocusLastPaneAction
impl Message for FocusLastPaneAction
Sourceimpl Message for FocusNextPaneAction
impl Message for FocusNextPaneAction
Sourceimpl Message for FocusPaneByPaneIdAction
impl Message for FocusPaneByPaneIdAction
Sourceimpl Message for FocusPreviousPaneAction
impl Message for FocusPreviousPaneAction
Sourceimpl Message for ForegroundColorMsg
impl Message for ForegroundColorMsg
Sourceimpl Message for ForwardQueryToHostMsg
impl Message for ForwardQueryToHostMsg
Sourceimpl Message for ForwardedReplyFromHostMsg
impl Message for ForwardedReplyFromHostMsg
Sourceimpl Message for FullscreenState
impl Message for FullscreenState
Sourceimpl Message for GoToNextTabAction
impl Message for GoToNextTabAction
Sourceimpl Message for GoToPreviousTabAction
impl Message for GoToPreviousTabAction
Sourceimpl Message for GoToTabAction
impl Message for GoToTabAction
Sourceimpl Message for GoToTabByIdAction
impl Message for GoToTabByIdAction
Sourceimpl Message for GoToTabNameAction
impl Message for GoToTabNameAction
Sourceimpl Message for HalfPageScrollDownAction
impl Message for HalfPageScrollDownAction
Sourceimpl Message for HalfPageScrollUpAction
impl Message for HalfPageScrollUpAction
Sourceimpl Message for HideFloatingPanesAction
impl Message for HideFloatingPanesAction
Sourceimpl Message for KeyWithModifier
impl Message for KeyWithModifier
Sourceimpl Message for KeybindPipeAction
impl Message for KeybindPipeAction
Sourceimpl Message for KillSessionMsg
impl Message for KillSessionMsg
Sourceimpl Message for KittyGraphicsSupportMsg
impl Message for KittyGraphicsSupportMsg
Sourceimpl Message for LaunchOrFocusPluginAction
impl Message for LaunchOrFocusPluginAction
Sourceimpl Message for LaunchPluginAction
impl Message for LaunchPluginAction
Sourceimpl Message for LayoutConstraintTiledPair
impl Message for LayoutConstraintTiledPair
Sourceimpl Message for LayoutConstraintWithValue
impl Message for LayoutConstraintWithValue
Sourceimpl Message for LayoutMetadata
impl Message for LayoutMetadata
Sourceimpl Message for ListClientsAction
impl Message for ListClientsAction
Sourceimpl Message for ListPanesAction
impl Message for ListPanesAction
Sourceimpl Message for ListTabsAction
impl Message for ListTabsAction
Sourceimpl Message for MobileActivePaneMsg
impl Message for MobileActivePaneMsg
Sourceimpl Message for MobilePaneMsg
impl Message for MobilePaneMsg
Sourceimpl Message for MobileRenderPrefsMsg
impl Message for MobileRenderPrefsMsg
Sourceimpl Message for MobileSessionMsg
impl Message for MobileSessionMsg
Sourceimpl Message for MobileSizeMsg
impl Message for MobileSizeMsg
Sourceimpl Message for MobileStateMsg
impl Message for MobileStateMsg
Sourceimpl Message for MouseEventAction
impl Message for MouseEventAction
Sourceimpl Message for MoveFocusAction
impl Message for MoveFocusAction
Sourceimpl Message for MoveFocusOrTabAction
impl Message for MoveFocusOrTabAction
Sourceimpl Message for MovePaneAction
impl Message for MovePaneAction
Sourceimpl Message for MovePaneBackwardsAction
impl Message for MovePaneBackwardsAction
Sourceimpl Message for MovePaneByPaneIdAction
impl Message for MovePaneByPaneIdAction
Sourceimpl Message for MoveTabAction
impl Message for MoveTabAction
Sourceimpl Message for MoveTabByTabIdAction
impl Message for MoveTabByTabIdAction
Sourceimpl Message for NestedSessionMessage
impl Message for NestedSessionMessage
Sourceimpl Message for NewBlockingPaneAction
impl Message for NewBlockingPaneAction
Sourceimpl Message for NewFloatingPaneAction
impl Message for NewFloatingPaneAction
Sourceimpl Message for NewInPlacePaneAction
impl Message for NewInPlacePaneAction
Sourceimpl Message for NewInPlacePluginPaneAction
impl Message for NewInPlacePluginPaneAction
Sourceimpl Message for NewPaneAction
impl Message for NewPaneAction
Sourceimpl Message for NewPanePlacement
impl Message for NewPanePlacement
Sourceimpl Message for NewPanePlacementInPlace
impl Message for NewPanePlacementInPlace
Sourceimpl Message for NewStackedPaneAction
impl Message for NewStackedPaneAction
Sourceimpl Message for NewTiledPaneAction
impl Message for NewTiledPaneAction
Sourceimpl Message for NewTiledPluginPaneAction
impl Message for NewTiledPluginPaneAction
Sourceimpl Message for NextSwapLayoutAction
impl Message for NextSwapLayoutAction
Sourceimpl Message for NoPreferencePlacement
impl Message for NoPreferencePlacement
Sourceimpl Message for OpenFilePayload
impl Message for OpenFilePayload
Sourceimpl Message for OriginatingPlugin
impl Message for OriginatingPlugin
Sourceimpl Message for OverrideLayoutAction
impl Message for OverrideLayoutAction
Sourceimpl Message for PageScrollDownAction
impl Message for PageScrollDownAction
Sourceimpl Message for PageScrollUpAction
impl Message for PageScrollUpAction
Sourceimpl Message for PageScrollUpByPaneIdAction
impl Message for PageScrollUpByPaneIdAction
Sourceimpl Message for PaneIdWithPlugin
impl Message for PaneIdWithPlugin
Sourceimpl Message for PaneNameInputAction
impl Message for PaneNameInputAction
Sourceimpl Message for PaneReference
impl Message for PaneReference
Sourceimpl Message for PaneRenderUpdateMsg
impl Message for PaneRenderUpdateMsg
Sourceimpl Message for PercentOrFixed
impl Message for PercentOrFixed
Sourceimpl Message for PixelDimensions
impl Message for PixelDimensions
Sourceimpl Message for PluginUserConfiguration
impl Message for PluginUserConfiguration
Sourceimpl Message for PreviousSwapLayoutAction
impl Message for PreviousSwapLayoutAction
Sourceimpl Message for QueryTabNamesAction
impl Message for QueryTabNamesAction
Sourceimpl Message for QueryTerminalSizeMsg
impl Message for QueryTerminalSizeMsg
Sourceimpl Message for RenamePaneByPaneIdAction
impl Message for RenamePaneByPaneIdAction
Sourceimpl Message for RenamePluginPaneAction
impl Message for RenamePluginPaneAction
Sourceimpl Message for RenameSessionAction
impl Message for RenameSessionAction
Sourceimpl Message for RenameTabAction
impl Message for RenameTabAction
Sourceimpl Message for RenameTabByIdAction
impl Message for RenameTabByIdAction
Sourceimpl Message for RenameTerminalPaneAction
impl Message for RenameTerminalPaneAction
Sourceimpl Message for RenamedSessionMsg
impl Message for RenamedSessionMsg
Sourceimpl Message for RequestSessionListMsg
impl Message for RequestSessionListMsg
Sourceimpl Message for ResizeByPaneIdAction
impl Message for ResizeByPaneIdAction
Sourceimpl Message for RunCommandAction
impl Message for RunCommandAction
Sourceimpl Message for RunEditFileAction
impl Message for RunEditFileAction
Sourceimpl Message for RunPluginLocationData
impl Message for RunPluginLocationData
Sourceimpl Message for RunPluginOrAlias
impl Message for RunPluginOrAlias
Sourceimpl Message for SaveSessionAction
impl Message for SaveSessionAction
Sourceimpl Message for ScrollDownAction
impl Message for ScrollDownAction
Sourceimpl Message for ScrollDownAtAction
impl Message for ScrollDownAtAction
Sourceimpl Message for ScrollDownByPaneIdAction
impl Message for ScrollDownByPaneIdAction
Sourceimpl Message for ScrollToBottomAction
impl Message for ScrollToBottomAction
Sourceimpl Message for ScrollToNextPromptAction
impl Message for ScrollToNextPromptAction
Sourceimpl Message for ScrollToTopAction
impl Message for ScrollToTopAction
Sourceimpl Message for ScrollToTopByPaneIdAction
impl Message for ScrollToTopByPaneIdAction
Sourceimpl Message for ScrollUpAction
impl Message for ScrollUpAction
Sourceimpl Message for ScrollUpAtAction
impl Message for ScrollUpAtAction
Sourceimpl Message for ScrollUpByPaneIdAction
impl Message for ScrollUpByPaneIdAction
Sourceimpl Message for SearchInputAction
impl Message for SearchInputAction
Sourceimpl Message for SearchToggleOptionAction
impl Message for SearchToggleOptionAction
Sourceimpl Message for ServerToClientMsg
impl Message for ServerToClientMsg
Sourceimpl Message for SetDarkThemeAction
impl Message for SetDarkThemeAction
Sourceimpl Message for SetLightThemeAction
impl Message for SetLightThemeAction
Sourceimpl Message for SetPaneBorderlessAction
impl Message for SetPaneBorderlessAction
Sourceimpl Message for SetPaneColorAction
impl Message for SetPaneColorAction
Sourceimpl Message for SetPaneFrameStyleAction
impl Message for SetPaneFrameStyleAction
Sourceimpl Message for SetSoftKeyboardMsg
impl Message for SetSoftKeyboardMsg
Sourceimpl Message for ShortcutUpdate
impl Message for ShortcutUpdate
Sourceimpl Message for ShowFloatingPanesAction
impl Message for ShowFloatingPanesAction
Sourceimpl Message for SixelSupportMsg
impl Message for SixelSupportMsg
Sourceimpl Message for SkipConfirmAction
impl Message for SkipConfirmAction
Sourceimpl Message for StackPanesAction
impl Message for StackPanesAction
Sourceimpl Message for StackedPlacement
impl Message for StackedPlacement
Sourceimpl Message for StartOrReloadPluginAction
impl Message for StartOrReloadPluginAction
Sourceimpl Message for StartWebServerMsg
impl Message for StartWebServerMsg
Sourceimpl Message for SubscribeToPaneRendersMsg
impl Message for SubscribeToPaneRendersMsg
Sourceimpl Message for SubscribedPaneClosedMsg
impl Message for SubscribedPaneClosedMsg
Sourceimpl Message for SwapFloatingLayout
impl Message for SwapFloatingLayout
Sourceimpl Message for SwapTiledLayout
impl Message for SwapTiledLayout
Sourceimpl Message for SwitchFocusAction
impl Message for SwitchFocusAction
Sourceimpl Message for SwitchSessionAction
impl Message for SwitchSessionAction
Sourceimpl Message for SwitchSessionMsg
impl Message for SwitchSessionMsg
Sourceimpl Message for SwitchToModeAction
impl Message for SwitchToModeAction
Sourceimpl Message for TabLayoutInfo
impl Message for TabLayoutInfo
Sourceimpl Message for TabNameInputAction
impl Message for TabNameInputAction
Sourceimpl Message for TerminalPixelDimensionsMsg
impl Message for TerminalPixelDimensionsMsg
Sourceimpl Message for TerminalResizeMsg
impl Message for TerminalResizeMsg
Sourceimpl Message for TiledPaneLayout
impl Message for TiledPaneLayout
Sourceimpl Message for TiledPlacement
impl Message for TiledPlacement
Sourceimpl Message for ToggleActiveSyncTabAction
impl Message for ToggleActiveSyncTabAction
Sourceimpl Message for ToggleFloatingPanesAction
impl Message for ToggleFloatingPanesAction
Sourceimpl Message for ToggleGroupMarkingAction
impl Message for ToggleGroupMarkingAction
Sourceimpl Message for ToggleHostFullscreen
impl Message for ToggleHostFullscreen
Sourceimpl Message for ToggleHostFullscreenAction
impl Message for ToggleHostFullscreenAction
Sourceimpl Message for ToggleMouseModeAction
impl Message for ToggleMouseModeAction
Sourceimpl Message for TogglePaneBorderlessAction
impl Message for TogglePaneBorderlessAction
Sourceimpl Message for TogglePaneFramesAction
impl Message for TogglePaneFramesAction
Sourceimpl Message for TogglePaneInGroupAction
impl Message for TogglePaneInGroupAction
Sourceimpl Message for TogglePanePinnedAction
impl Message for TogglePanePinnedAction
Sourceimpl Message for ToggleTabAction
impl Message for ToggleTabAction
Sourceimpl Message for ToggleThemeAction
impl Message for ToggleThemeAction
Sourceimpl Message for UnblockCliPipeInputMsg
impl Message for UnblockCliPipeInputMsg
Sourceimpl Message for UnblockInputThreadMsg
impl Message for UnblockInputThreadMsg
Sourceimpl Message for UndoRenamePaneAction
impl Message for UndoRenamePaneAction
Sourceimpl Message for UndoRenameTabAction
impl Message for UndoRenameTabAction
Sourceimpl Message for UndoRenameTabByTabIdAction
impl Message for UndoRenameTabByTabIdAction
Sourceimpl Message for WebServerStartedMsg
impl Message for WebServerStartedMsg
Sourceimpl Message for WriteCharsAction
impl Message for WriteCharsAction
Sourceimpl Message for WriteCharsToPaneIdAction
impl Message for WriteCharsToPaneIdAction
Sourceimpl Message for WriteToPaneIdAction
impl Message for WriteToPaneIdAction
Implementors
impl Message for zellij_tile::shim::plugin_api::action::ProtobufAction
impl Message for ActionCompletePayload
impl Message for ActivePaneScrollPayload
impl Message for AreFloatingPanesVisiblePayload
impl Message for Arg
impl Message for AvailableLayoutInfoPayload
impl Message for BreakPanesToNewTabPayload
impl Message for BreakPanesToNewTabResponse
impl Message for BreakPanesToTabWithIdPayload
impl Message for BreakPanesToTabWithIdResponse
impl Message for BreakPanesToTabWithIndexPayload
impl Message for BreakPanesToTabWithIndexResponse
impl Message for Bytes
google.protobuf.BytesValue
impl Message for ChangeFloatingPanesCoordinatesPayload
impl Message for ChangeHostFolderPayload
impl Message for ClearPaneHighlightsPayload
impl Message for ClearScreenForPaneIdPayload
impl Message for CliPipeOutputPayload
impl Message for CliPipePayload
impl Message for ClientInfo
impl Message for ClientPaneHistory
impl Message for ClientTabHistory
impl Message for CloseMultiplePanesPayload
impl Message for CloseTabWithIdPayload
impl Message for CloseTabWithIndexPayload
impl Message for Color
impl Message for Command
impl Message for CommandChangedPayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufCommandOrPlugin
impl Message for zellij_tile::shim::plugin_api::generated_api::api::action::CommandOrPluginFile
impl Message for CommandPaneExitedPayload
impl Message for CommandPaneOpenedPayload
impl Message for CommandPaneReRunPayload
impl Message for zellij_tile::shim::plugin_api::event::ProtobufContextItem
impl Message for zellij_tile::shim::plugin_api::plugin_command::ContextItem
impl Message for CopyToClipboardPayload
impl Message for CreateTokenResponse
impl Message for CurrentSessionLastSavedTimePayload
impl Message for CurrentSessionLastSavedTimeResponse
impl Message for CursorPosition
impl Message for CustomIndexHighlight
impl Message for CustomMessagePayload
impl Message for CustomRgbHighlight
impl Message for CwdChangedPayload
impl Message for DeleteAllDeadSessionsResponse
impl Message for DeleteDeadSessionResponse
impl Message for DeleteLayoutPayload
impl Message for DeleteLayoutResponse
impl Message for DumpLayoutPayload
impl Message for DumpLayoutResponse
impl Message for DumpScreenPayload
impl Message for DumpSessionLayoutPayload
impl Message for DumpSessionLayoutResponse
impl Message for EditFilePayload
impl Message for EditLayoutPayload
impl Message for EditLayoutResponse
impl Message for EditPaneExitedPayload
impl Message for EditPaneOpenedPayload
impl Message for EditScrollbackForPaneWithIdPayload
impl Message for EmbedMultiplePanesPayload
impl Message for EnvVariable
impl Message for Event
impl Message for EventNameList
impl Message for ExecCmdPayload
impl Message for FailedToChangeHostFolderPayload
impl Message for FailedToStartWebServerPayload
impl Message for FailedToWriteConfigToDiskPayload
impl Message for File
impl Message for FileListPayload
impl Message for FileMetadata
impl Message for FixedOrPercentValue
impl Message for FloatMultiplePanesPayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufFloatingPaneCoordinates
impl Message for zellij_tile::shim::plugin_api::plugin_command::ProtobufFloatingPaneCoordinates
impl Message for zellij_tile::shim::plugin_api::action::ProtobufFloatingPaneLayout
impl Message for FloatingPlacement
impl Message for FocusOrCreateTabResponse
impl Message for FocusedPaneInfo
impl Message for GenerateRandomNamePayload
impl Message for GenerateRandomNameResponse
impl Message for GenerateWebLoginTokenPayload
impl Message for GetFocusedPaneInfoPayload
impl Message for GetFocusedPaneInfoResponse
impl Message for GetLayoutDirPayload
impl Message for GetLayoutDirResponse
impl Message for GetPaneCwdPayload
impl Message for GetPaneCwdResponse
impl Message for GetPaneInfoPayload
impl Message for GetPaneInfoResponse
impl Message for GetPanePidPayload
impl Message for GetPanePidResponse
impl Message for GetPaneRunningCommandPayload
impl Message for GetPaneRunningCommandResponse
impl Message for GetPaneScrollbackPayload
impl Message for GetSessionEnvironmentVariablesPayload
impl Message for GetSessionEnvironmentVariablesResponse
impl Message for GetSessionListPayload
impl Message for GetSessionListResponse
impl Message for GetTabInfoPayload
impl Message for GetTabInfoResponse
impl Message for GoToTabNamePayload
impl Message for GoToTabWithIdPayload
impl Message for GroupAndUngroupPanesPayload
impl Message for Header
impl Message for zellij_tile::shim::plugin_api::action::HideFloatingPanesPayload
impl Message for zellij_tile::shim::plugin_api::plugin_command::ProtobufHideFloatingPanesPayload
impl Message for HideFloatingPanesResponse
impl Message for HidePaneWithIdPayload
impl Message for HighlightAndUnhighlightPanesPayload
impl Message for HighlightClickedPayload
impl Message for HighlightStyle
impl Message for HintTextPayload
impl Message for HostFolderChangedPayload
impl Message for HostTerminalThemeChangedPayload
impl Message for IdAndName
impl Message for IdAndNewName
impl Message for InPlaceConfig
impl Message for IndexInPaneGroup
impl Message for InitialKeybindsPayload
impl Message for InputModeKeybinds
impl Message for InputModeMessage
impl Message for KdlError
impl Message for KdlErrorVariant
impl Message for Key
impl Message for KeyBind
impl Message for KeyToRebind
impl Message for KeyToUnbind
impl Message for zellij_tile::shim::plugin_api::action::ProtobufKeyWithModifier
impl Message for KillSessionsPayload
impl Message for KillSessionsResponse
impl Message for LaunchOrFocusPluginPayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufLayoutConstraintFloatingPair
impl Message for zellij_tile::shim::plugin_api::action::ProtobufLayoutConstraintTiledPair
impl Message for zellij_tile::shim::plugin_api::action::ProtobufLayoutConstraintWithValue
impl Message for zellij_tile::shim::plugin_api::event::ProtobufLayoutInfo
impl Message for zellij_tile::shim::plugin_api::event::ProtobufLayoutMetadata
impl Message for LayoutParsingError
impl Message for LayoutWithError
impl Message for ListClientsPayload
impl Message for ListTokensResponse
impl Message for LoadNewPluginPayload
impl Message for Message
impl Message for MessageToPluginPayload
impl Message for ModeUpdatePayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufMouseEventPayload
impl Message for zellij_tile::shim::plugin_api::event::MouseEventPayload
impl Message for MoveDirection
impl Message for MovePanePayload
impl Message for MovePaneWithPaneIdInDirectionPayload
impl Message for MovePaneWithPaneIdPayload
impl Message for MovePayload
impl Message for NameAndValue
impl Message for NewBlockingPanePayload
impl Message for NewFloatingPanePayload
impl Message for NewInPlacePanePayload
impl Message for NewPanePayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufNewPanePlacement
impl Message for NewPluginArgs
impl Message for NewPluginPanePayload
impl Message for zellij_tile::shim::plugin_api::action::NewTabPayload
impl Message for zellij_tile::shim::plugin_api::plugin_command::NewTabPayload
impl Message for NewTabResponse
impl Message for NewTabUnfocusedPayload
impl Message for NewTabUnfocusedResponse
impl Message for NewTabsResponse
impl Message for NewTabsWithLayoutInfoPayload
impl Message for NewTiledPaneInTabPayload
impl Message for NewTiledPaneInTabResponse
impl Message for NewTiledPanePayload
impl Message for NoPreferenceOptions
impl Message for OpenCommandPaneBackgroundResponse
impl Message for OpenCommandPaneFloatingNearPluginPayload
impl Message for OpenCommandPaneFloatingNearPluginResponse
impl Message for OpenCommandPaneFloatingResponse
impl Message for OpenCommandPaneInPlaceOfPaneIdPayload
impl Message for OpenCommandPaneInPlaceOfPaneIdResponse
impl Message for OpenCommandPaneInPlaceOfPluginPayload
impl Message for OpenCommandPaneInPlaceOfPluginResponse
impl Message for OpenCommandPaneInPlaceResponse
impl Message for OpenCommandPaneNearPluginPayload
impl Message for OpenCommandPaneNearPluginResponse
impl Message for OpenCommandPanePayload
impl Message for OpenCommandPaneResponse
impl Message for OpenEditPaneInPlaceOfPaneIdPayload
impl Message for OpenEditPaneInPlaceOfPaneIdResponse
impl Message for OpenFileFloatingNearPluginPayload
impl Message for OpenFileFloatingNearPluginResponse
impl Message for OpenFileFloatingResponse
impl Message for OpenFileInPlaceOfPluginPayload
impl Message for OpenFileInPlaceOfPluginResponse
impl Message for OpenFileInPlaceResponse
impl Message for OpenFileNearPluginPayload
impl Message for OpenFileNearPluginResponse
impl Message for zellij_tile::shim::plugin_api::plugin_command::OpenFilePayload
impl Message for OpenFileResponse
impl Message for OpenPaneInNewTabResponse
impl Message for OpenPluginPaneFloatingPayload
impl Message for OpenPluginPaneFloatingResponse
impl Message for OpenPluginPaneInNewTabPayload
impl Message for OpenTerminalFloatingNearPluginPayload
impl Message for OpenTerminalFloatingNearPluginResponse
impl Message for OpenTerminalFloatingResponse
impl Message for OpenTerminalInPlaceOfPluginPayload
impl Message for OpenTerminalInPlaceOfPluginResponse
impl Message for OpenTerminalInPlaceResponse
impl Message for OpenTerminalNearPluginPayload
impl Message for OpenTerminalNearPluginResponse
impl Message for OpenTerminalPaneInPlaceOfPaneIdPayload
impl Message for OpenTerminalPaneInPlaceOfPaneIdResponse
impl Message for OpenTerminalResponse
impl Message for zellij_tile::shim::plugin_api::action::OverrideLayoutPayload
impl Message for zellij_tile::shim::plugin_api::plugin_command::OverrideLayoutPayload
impl Message for PageScrollDownInPaneIdPayload
impl Message for PageScrollUpInPaneIdPayload
impl Message for Palette
impl Message for PaneClosedPayload
impl Message for PaneContents
impl Message for PaneContentsEntry
impl Message for zellij_tile::shim::plugin_api::action::ProtobufPaneId
impl Message for zellij_tile::shim::plugin_api::event::ProtobufPaneId
impl Message for zellij_tile::shim::plugin_api::plugin_command::ProtobufPaneId
impl Message for PaneIdAndFloatingPaneCoordinates
impl Message for PaneIdAndShouldFloat
impl Message for PaneInfo
impl Message for PaneManifest
impl Message for zellij_tile::shim::plugin_api::event::ProtobufPaneMetadata
impl Message for PaneRenderReportPayload
impl Message for PaneRun
impl Message for PaneScrollbackResponse
impl Message for PaneUpdatePayload
impl Message for ParseLayoutPayload
impl Message for ParseLayoutResponse
impl Message for PastedTextPayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufPercentOrFixed
impl Message for PermissionRequestResultPayload
impl Message for PipeMessage
impl Message for zellij_tile::shim::plugin_api::action::ProtobufPluginAlias
impl Message for PluginCommand
impl Message for PluginConfiguration
impl Message for PluginConfigurationChangedPayload
impl Message for PluginIds
impl Message for PluginInfo
impl Message for PluginMessagePayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufPluginTag
impl Message for zellij_tile::shim::plugin_api::action::ProtobufPluginUserConfiguration
impl Message for zellij_tile::shim::plugin_api::action::ProtobufPosition
impl Message for RebindKeysPayload
impl Message for ReconfigurePayload
impl Message for RegexHighlight
impl Message for ReloadPluginPayload
impl Message for RenameLayoutPayload
impl Message for RenameLayoutResponse
impl Message for RenameTabWithIdPayload
impl Message for RenameWebLoginTokenPayload
impl Message for RenameWebTokenResponse
impl Message for ReplacePaneWithExistingPanePayload
impl Message for RequestPluginPermissionPayload
impl Message for RerunCommandPanePayload
impl Message for Resize
impl Message for ResizePaneIdWithDirectionPayload
impl Message for ResizePayload
impl Message for ResurrectableSession
impl Message for RevokeAllWebTokensResponse
impl Message for RevokeTokenResponse
impl Message for RevokeWebLoginTokenPayload
impl Message for RgbColorPayload
impl Message for RunActionPayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufRunCommandAction
impl Message for RunCommandPayload
impl Message for RunCommandResultPayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufRunEditFileAction
impl Message for zellij_tile::shim::plugin_api::action::ProtobufRunPlugin
impl Message for zellij_tile::shim::plugin_api::action::ProtobufRunPluginLocationData
impl Message for zellij_tile::shim::plugin_api::action::ProtobufRunPluginOrAlias
impl Message for RunningCommand
impl Message for SaveLayoutPayload
impl Message for SaveLayoutResponse
impl Message for SaveSessionPayload
impl Message for SaveSessionResponse
impl Message for ScrollAtPayload
impl Message for ScrollDownInPaneIdPayload
impl Message for ScrollToBottomInPaneIdPayload
impl Message for ScrollToTopInPaneIdPayload
impl Message for ScrollUpInPaneIdPayload
impl Message for SelectedText
impl Message for SessionListSnapshot
impl Message for SessionManifest
impl Message for SessionUpdatePayload
impl Message for SetFloatingPanePinnedPayload
impl Message for zellij_tile::shim::plugin_api::generated_api::api::action::SetPaneBorderlessPayload
impl Message for zellij_tile::shim::plugin_api::plugin_command::SetPaneBorderlessPayload
impl Message for SetPaneColorPayload
impl Message for zellij_tile::shim::plugin_api::action::SetPaneFrameStylePayload
impl Message for zellij_tile::shim::plugin_api::plugin_command::ProtobufSetPaneFrameStylePayload
impl Message for SetPaneRegexHighlightsPayload
impl Message for SetSelfMouseSelectionSupportPayload
impl Message for SetSoftKeyboardPayload
impl Message for SetTimeoutPayload
impl Message for ShowCursorPayload
impl Message for zellij_tile::shim::plugin_api::action::ShowFloatingPanesPayload
impl Message for zellij_tile::shim::plugin_api::plugin_command::ProtobufShowFloatingPanesPayload
impl Message for ShowFloatingPanesResponse
impl Message for ShowPaneWithIdPayload
impl Message for SoftKeyboardVisibilityChangedPayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufSplitSize
impl Message for StackPanesPayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufStackedPlacement
impl Message for String
google.protobuf.StringValue
impl Message for zellij_tile::shim::plugin_api::event::ProtobufStyle
impl Message for StyledText
impl Message for StyledTextIndices
impl Message for zellij_tile::shim::plugin_api::generated_api::api::style::Styling
impl Message for SubscribePayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufSwapFloatingLayout
impl Message for zellij_tile::shim::plugin_api::action::ProtobufSwapTiledLayout
impl Message for SwitchSessionPayload
impl Message for SwitchTabToIdPayload
impl Message for SwitchTabToPayload
impl Message for SwitchToModePayload
impl Message for SyntaxError
impl Message for TabIdAndName
impl Message for TabInfo
impl Message for zellij_tile::shim::plugin_api::action::ProtobufTabLayoutInfo
impl Message for zellij_tile::shim::plugin_api::event::ProtobufTabMetadata
impl Message for TabUpdatePayload
impl Message for zellij_tile::shim::plugin_api::action::ProtobufTiledPaneLayout
impl Message for zellij_tile::shim::plugin_api::action::ProtobufTiledPlacement
impl Message for ToggleFloatingPanesPayload
impl Message for TogglePaneBorderlessPayload
impl Message for TogglePaneEmbedOrEjectForPaneIdPayload
impl Message for TogglePaneIdFullscreenPayload
impl Message for UnsubscribePayload
impl Message for UserActionPayload
impl Message for Vec<u8>
google.protobuf.BytesValue